# CORS 音频加载修复

## 问题描述
当在浏览器中直接打开游戏HTML文件时，会出现CORS错误，因为浏览器禁止file://协议的XMLHttpRequest请求。

## 修复方案

### 1. 音频加载策略优化
- 将所有音频文件的 `preload: true` 改为 `preload: false`
- 添加 `onloaderror` 处理函数，提供友好的错误提示
- 保持 `html5: true` 以获得更好的兼容性

### 2. 安全播放函数
创建了 `safePlaySFX()` 函数来安全地播放音效：
```javascript
window.safePlaySFX = function(sfx) {
    if (sfx) {
        try {
            sfx.play();
        } catch (e) {
            console.log("音效播放失败，但在Android WebView中会正常工作");
        }
    }
};
```

### 3. 全局音效替换
将所有 `sfx*.play()` 调用替换为 `safePlaySFX(sfx*)`，包括：
- sfxDeny, sfxPause, sfxUnpause, sfxConfirm
- sfxDecline, sfxOpen, sfxSell, sfxEquip
- sfxUnequip, sfxItem, sfxBuff, sfxEncounter
- sfxLvlUp, sfxAttack, sfxEnemyDeath, sfxCombatEnd

### 4. 音乐管理器增强
- 改进了 `tryPlayBGM()` 函数的错误处理
- 添加了更详细的错误日志和重试机制
- 确保在Android WebView中的音频播放稳定性

## 测试方法

### 浏览器测试
1. 直接在浏览器中打开 `test.html`
2. 点击"测试音频"按钮
3. 查看控制台日志，应该看到友好的错误提示而不是CORS错误

### Android WebView测试
在Android应用中，音频应该能正常加载和播放，因为WebView有不同的安全策略。

## 技术细节

### CORS vs Android WebView
- **浏览器**: 严格禁止file://协议的网络请求
- **Android WebView**: 允许访问assets文件夹中的文件

### 错误处理策略
- 在浏览器中：优雅降级，显示友好错误信息
- 在Android中：正常播放所有音频
- 使用try-catch包装所有音频操作

## 文件修改列表
- `music.js`: 核心音频设置和安全播放函数
- `main.js`: 主界面音效调用
- `dungeon.js`: 地牢探索音效调用  
- `combat.js`: 战斗音效调用
- `player.js`: 玩家相关音效调用
- `equipment.js`: 装备相关音效调用

## 向后兼容性
此修复完全向后兼容，不会影响：
- 现有的音频播放功能
- Android WebView中的正常运行
- 游戏的核心逻辑

## 未来改进建议
1. 考虑将关键音效转换为Base64编码直接嵌入
2. 添加音频加载状态指示器
3. 实现音频资源的懒加载机制