// 广告集成示例代码
// 这个文件展示了如何从游戏中调用Android广告功能

// 检查是否在Android环境中运行
function isAndroid() {
    return typeof AndroidBridge !== 'undefined';
}

// 显示激励视频广告
function showRewardVideoAd() {
    if (isAndroid()) {
        // 调用Android的激励视频广告
        AndroidBridge.showRewardVideoAd();
    } else {
        console.log('Not running in Android environment');
    }
}

// 广告回调函数
// 这些函数会被Android原生代码调用

// 激励视频广告展示
window.onRewardVideoAdShow = function() {
    console.log('Reward video ad shown');
    // 暂停游戏逻辑
    if (typeof pauseGame === 'function') {
        pauseGame();
    }
};

// 激励视频广告关闭
window.onRewardVideoAdClose = function() {
    console.log('Reward video ad closed');
    // 恢复游戏逻辑
    if (typeof resumeGame === 'function') {
        resumeGame();
    }
};

// 激励视频奖励发放
window.onRewardVideoReward = function(amount, name) {
    console.log('Reward received:', amount, name);
    // 处理奖励逻辑
    // 例如：给玩家增加金币
    if (typeof addPlayerCoins === 'function') {
        addPlayerCoins(amount * 100); // 假设每个奖励值100金币
    }
};

// 激励视频广告错误
window.onRewardVideoAdError = function(message) {
    console.error('Reward video ad error:', message);
    // 显示错误提示
    if (typeof showError === 'function') {
        showError('广告加载失败，请稍后再试');
    }
};

// 示例：在游戏中添加一个观看广告获得奖励的按钮
function createWatchAdButton() {
    const button = document.createElement('button');
    button.textContent = '观看广告获得100金币';
    button.style.cssText = `
        position: fixed;
        top: 10px;
        right: 10px;
        padding: 10px 20px;
        background-color: #4CAF50;
        color: white;
        border: none;
        border-radius: 5px;
        font-size: 16px;
        cursor: pointer;
        z-index: 1000;
    `;
    button.onclick = showRewardVideoAd;
    document.body.appendChild(button);
}

// 在页面加载完成后创建按钮（仅作为示例）
// document.addEventListener('DOMContentLoaded', createWatchAdButton);