const combatPanel = document.querySelector("#combatPanel")
let enemyDead = false;
let playerDead = false;
let reviveCount = 0; // 当前闯关的复活次数

// ========== Validation ==========
const hpValidation = () => {
    // Prioritizes player death before the enemy
    if (player.stats.hp < 1) {
        player.stats.hp = 0;
        playerDead = true;
        player.deaths++;
        addCombatLog(`系统失效！`);
        endCombat();
        
        // 延迟显示弹窗，确保UI更新完成
        setTimeout(() => {
            // 如果还有复活机会，显示复活选项
            if (reviveCount < 1) {
                showReviveOptions();
            } else {
                // 没有复活机会了，确保战斗面板可交互并更新战斗日志
                if (combatPanel) {
                    combatPanel.style.filter = "brightness(100%)";
                }
                updateCombatLog();
            }
        }, 100);
    } else if (enemy.stats.hp < 1) {
        // Gives out all the reward and show the claim button
        enemy.stats.hp = 0;
        enemyDead = true;
        player.kills++;
        dungeon.statistics.kills++;
        addCombatLog(`${enemy.name} 已摧毁！ (${new Date(combatSeconds * 1000).toISOString().substring(14, 19)})`);
        addCombatLog(`获得 ${nFormatter(enemy.rewards.exp)} 系统经验。`)
        playerExpGain();
        // 存储战斗金币奖励，待玩家选择后发放
        window.pendingCombatGold = safeNumber(enemy.rewards.gold, 10);
        if (enemy.rewards.drop) {
            createEquipmentPrint("combat");
        }

        // Recover 20% of players health
        player.stats.hp += Math.round((player.stats.hpMax * 20) / 100);
        playerLoadStats();

        // 战斗结束处理已经在 updateCombatLog 中设置
        endCombat();
    }
}

// ========== Attack Functions ==========
const playerAttack = () => {
    if (!player.inCombat) {
        return;
    }
    if (player.inCombat) {
        safePlaySFX(sfxAttack);
    }

    // Calculates the damage and attacks the enemy
    let crit;
    let damage = player.stats.atk * (player.stats.atk / (player.stats.atk + enemy.stats.def));
    // Randomizes the damage by 90% - 110%
    let dmgRange = 0.9 + Math.random() * 0.2;
    damage = damage * dmgRange;
    // Check if the attack is a critical hit
    if (Math.floor(Math.random() * 100) < player.stats.critRate) {
        crit = true;
        dmgtype = "致命打击";
        damage = Math.round(damage * (1 + (player.stats.critDmg / 100)));
    } else {
        crit = false;
        dmgtype = "伤害";
        damage = Math.round(damage);
    }

    // Skill effects
    objectValidation();
    if (player.skills.includes("Remnant Razor")) {
        // Attacks deal extra 8% of enemies' current health on hit
        damage += Math.round((8 * enemy.stats.hp) / 100);
    }
    if (player.skills.includes("Titan's Will")) {
        // Attacks deal extra 5% of your maximum health on hit
        damage += Math.round((5 * player.stats.hpMax) / 100);
    }
    if (player.skills.includes("Devastator")) {
        // Deal 30% more damage but you lose 30% base attack speed
        damage = Math.round(damage + ((30 * damage) / 100));
    }
    if (player.skills.includes("Rampager")) {
        // Increase base attack by 5 after each hit. Stack resets after battle.
        player.baseStats.atk += 5;
        objectValidation();
        player.tempStats.atk += 5;
        saveData();
    }
    if (player.skills.includes("Blade Dance")) {
        // Gain increased attack speed after each hit. Stack resets after battle
        player.baseStats.atkSpd += 0.01;
        objectValidation();
        player.tempStats.atkSpd += 0.01;
        saveData();
    }

    // Lifesteal formula
    let lifesteal = Math.round(damage * (player.stats.vamp / 100));

    // Apply the calculations to combat
    enemy.stats.hp -= damage;
    player.stats.hp += lifesteal;
    addCombatLog(`${player.name} 对 ${enemy.name} 输出 ` + nFormatter(damage) + ` ${dmgtype}。`);
    hpValidation();
    playerLoadStats();
    enemyLoadStats();

    // Damage effect - 改为敌人名称震动效果
    let enemyDisplay = document.querySelector("#enemy-name-display");
    if (enemyDisplay) {
        enemyDisplay.classList.add("animation-shake");
        setTimeout(() => {
            enemyDisplay.classList.remove("animation-shake");
        }, 200);
    }

    // Damage numbers
    const dmgContainer = document.querySelector("#dmg-container");
    const dmgNumber = document.createElement("p");
    dmgNumber.classList.add("dmg-numbers");
    
    // 添加随机位置偏移
    const randomX = (Math.random() - 0.5) * 100; // -50px 到 50px
    const randomY = (Math.random() - 0.5) * 60;  // -30px 到 30px
    dmgNumber.style.transform = `translate(${randomX}px, ${randomY}px)`;
    dmgNumber.style.position = 'relative';
    
    if (crit) {
        dmgNumber.style.color = "gold";
        dmgNumber.innerHTML = nFormatter(damage) + "!";
    } else {
        dmgNumber.innerHTML = nFormatter(damage);
    }
    dmgContainer.appendChild(dmgNumber);
    setTimeout(() => {
        if (dmgContainer.lastElementChild) {
            dmgContainer.removeChild(dmgContainer.lastElementChild);
        }
    }, 370);

    // Attack Timer
    if (player.inCombat) {
        setTimeout(() => {
            if (player.inCombat) {
                playerAttack();
            }
        }, (1000 / player.stats.atkSpd));
    }
}

const enemyAttack = () => {
    if (!player.inCombat) {
        return;
    }
    if (player.inCombat) {
        safePlaySFX(sfxAttack);
    }

    // Calculates the damage and attacks the player
    let damage = enemy.stats.atk * (enemy.stats.atk / (enemy.stats.atk + player.stats.def));
    let lifesteal = Math.round(enemy.stats.atk * (enemy.stats.vamp / 100));
    // Randomizes the damage by 90% - 110%
    let dmgRange = 0.9 + Math.random() * 0.2;
    damage = damage * dmgRange;
    // Check if the attack is a critical hit
    if (Math.floor(Math.random() * 100) < enemy.stats.critRate) {
        dmgtype = "致命打击";
        damage = Math.round(damage * (1 + (enemy.stats.critDmg / 100)));
    } else {
        dmgtype = "伤害";
        damage = Math.round(damage);
    }

    // Skill effects
    if (player.skills.includes("Paladin's Heart")) {
        // You receive 25% less damage
        damage = Math.round(damage - ((25 * damage) / 100));
    }

    // Apply the calculations
    player.stats.hp -= damage;
    // Aegis Thorns skill
    objectValidation();
    if (player.skills.includes("Aegis Thorns")) {
        // Enemies receive 15% of the damage they dealt
        enemy.stats.hp -= Math.round((15 * damage) / 100);
    }
    enemy.stats.hp += lifesteal;
    addCombatLog(`${enemy.name} 对 ${player.name} 输出 ` + nFormatter(damage) + ` ${dmgtype}。`);
    hpValidation();
    playerLoadStats();
    enemyLoadStats();

    // Damage effect - 玩家面板震动效果
    let playerPanel = document.querySelector('#playerPanel');
    playerPanel.classList.add("animation-shake");
    setTimeout(() => {
        playerPanel.classList.remove("animation-shake");
    }, 200);

    // Player damage numbers - 玩家受到伤害的数字显示
    const playerDmgContainer = document.querySelector("#player-dmg-container");
    if (playerDmgContainer) {
        const playerDmgNumber = document.createElement("p");
        playerDmgNumber.classList.add("player-dmg-numbers");
        
        // 添加随机位置偏移
        const randomX = (Math.random() - 0.5) * 80; // -40px 到 40px
        const randomY = (Math.random() - 0.5) * 50; // -25px 到 25px
        playerDmgNumber.style.transform = `translate(${randomX}px, ${randomY}px)`;
        playerDmgNumber.style.position = 'relative';
        
        if (dmgtype === "致命打击") {
            playerDmgNumber.style.color = "#ff6b6b"; // 红色表示玩家受到致命伤害
            playerDmgNumber.innerHTML = "-" + nFormatter(damage) + "!";
        } else {
            playerDmgNumber.style.color = "#ff9999"; // 淡红色表示玩家受到普通伤害
            playerDmgNumber.innerHTML = "-" + nFormatter(damage);
        }
        playerDmgContainer.appendChild(playerDmgNumber);
        setTimeout(() => {
            if (playerDmgContainer.lastElementChild) {
                playerDmgContainer.removeChild(playerDmgContainer.lastElementChild);
            }
        }, 370);
    }

    // Attack Timer
    if (player.inCombat) {
        setTimeout(() => {
            if (player.inCombat) {
                enemyAttack();
            }
        }, (1000 / enemy.stats.atkSpd));
    }
}

// ========== Combat Backlog ==========
const combatBacklog = [];

// Add a log to the combat backlog
const addCombatLog = (message) => {
    combatBacklog.push(message);
    updateCombatLog();
}

// Displays every combat activity
const updateCombatLog = () => {
    let combatLogBox = document.getElementById("combatLogBox");
    combatLogBox.innerHTML = "";

    for (let message of combatBacklog) {
        let logElement = document.createElement("p");
        logElement.innerHTML = message;
        combatLogBox.appendChild(logElement);
    }

    if (enemyDead) {
        let button = document.createElement("div");
        button.className = "decision-panel";
        button.innerHTML = `<button id="battleButton">回收资源</button>`;
        combatLogBox.appendChild(button);
        
        // 使用setTimeout确保按钮已添加到DOM
        setTimeout(() => {
            const battleBtn = document.querySelector("#battleButton");
            if (battleBtn && !battleBtn.hasAttribute('data-listener-attached')) {
                battleBtn.setAttribute('data-listener-attached', 'true');
                battleBtn.addEventListener("click", function() {
                    safePlaySFX(sfxConfirm);

                    // Clear combat backlog and transition to dungeon exploration
                    let dimDungeon = document.querySelector('#dungeon-main');
                    dimDungeon.style.filter = "brightness(100%)";
                    MusicManager.playBGM('dungeon');

                    combatPanel.style.display = "none";
                    enemyDead = false;
                    combatBacklog.length = 0;
                    
                    // 如果玩家处于暂停状态，重新开始休息血量恢复
                    if (dungeon.status.paused) {
                        startResting();
                    }
                    
                    // 立即重置事件状态，因为玩家已经选择退出战斗
                    dungeon.status.event = false;
                    
                    // 清除任何遗留的事件选择按钮（战斗是从事件开始的）
                    updateDungeonLog();
                    
                    // 显示金币双倍选项（如果有奖励）
                    if (window.pendingCombatGold > 0) {
                        showCombatGoldOptions(window.pendingCombatGold);
                        window.pendingCombatGold = 0;
                    }
                    
                    // 更新按钮状态
                    updateDungeonActivityButton();
                });
            }
        }, 50);
    }

    if (playerDead) {
        let button = document.createElement("div");
        button.className = "decision-panel";
        button.innerHTML = `<button id="battleButton">系统重启</button>`;
        combatLogBox.appendChild(button);
        
        // 添加事件监听器 - 使用setTimeout确保按钮已添加到DOM
        setTimeout(() => {
            const battleBtn = document.querySelector("#battleButton");
            if (battleBtn && !battleBtn.hasAttribute('data-listener-attached')) {
                battleBtn.setAttribute('data-listener-attached', 'true');
                battleBtn.addEventListener("click", function () {
                    safePlaySFX(sfxOpen);
                    
                    // 立即标记死亡状态并保存，防止刷新逃避
                    player.pendingDeathPenalty = true;
                    saveData();
                    
                    // 显示死亡惩罚提示
                    confirmationModalElement.style.display = "flex";
                    confirmationModalElement.innerHTML = `
                    <div class="content">
                        <h3><i class="fas fa-skull"></i> 系统崩溃</h3>
                        <p>装甲核心已失效，需要重启</p>
                        
                        <div style="margin: 1rem 0; font-size: 0.9rem;">
                            <p style="margin: 0.5rem 0;"><i class="fas fa-coins"></i> 信用点损失：${nFormatter(player.gold)} → ${nFormatter(Math.floor(player.gold / 2))}</p>
                            <p style="margin: 0.5rem 0;"><i class="fas fa-undo-alt"></i> 星区重置：返回第1区</p>
                            <p style="margin: 0.5rem 0;"><i class="fas fa-level-down-alt"></i> 等级归零：Mk.${player.lvl} → Mk.1</p>
                            <p style="margin: 0.5rem 0; color: #4CAF50;"><i class="fas fa-shield-alt"></i> 装备保留：不会丢失</p>
                        </div>
                        
                        <p style="font-size: 0.85rem; opacity: 0.7;">重启后将返回登录界面</p>
                        
                        <div class="button-container">
                            <button id="confirm-restart"><i class="fas fa-power-off"></i>重启系统</button>
                        </div>
                    </div>`;
                    
                    document.querySelector("#confirm-restart").onclick = function() {
                        safePlaySFX(sfxConfirm);
                        confirmationModalElement.style.display = "none";
                        confirmationModalElement.innerHTML = "";
                        playerDead = false;
                        
                        // 清除死亡标记
                        delete player.pendingDeathPenalty;

                        // Reset all the necessary stats and return to menu
                        let dimDungeon = document.querySelector('#dungeon-main');
                        dimDungeon.style.filter = "brightness(100%)";
                        dimDungeon.style.display = "none";
                        combatPanel.style.display = "none";
                        runLoad("title-screen", "flex");

                        clearInterval(dungeonTimer);
                        clearInterval(playTimer);
                        progressReset();
                    };
                });
            }
        }, 50);
    }

    combatLogBox.scrollTop = combatLogBox.scrollHeight;
}

// Combat Timer
let combatSeconds = 0;

const startCombat = (battleMusicType) => {
    console.log('开始战斗 - 初始化战斗系统...');
    
    safePlaySFX(sfxEncounter);
    MusicManager.playBGM(battleMusicType);
    player.inCombat = true;

    // 不再自动满血，保持当前血量进入战斗

    // 先显示战斗界面，然后开始攻击
    let dimDungeon = document.querySelector('#dungeon-main');
    dimDungeon.style.filter = "brightness(50%)";

    playerLoadStats();
    enemyLoadStats();

    dungeon.status.event = true;
    combatPanel.style.display = "flex";
    
    // 强制更新按钮状态
    if (typeof updateDungeonActivityButton === 'function') {
        updateDungeonActivityButton();
    }

    // 立即启动攻击，避免状态不一致
    console.log('启动玩家攻击循环');
    setTimeout(playerAttack, 100);
    
    console.log('启动敌人攻击循环');
    setTimeout(enemyAttack, Math.max(500, 1000 / enemy.stats.atkSpd));

    combatTimer = setInterval(combatCounter, 1000);
    
    console.log('战斗系统初始化完成');
}

const endCombat = () => {
    console.log('战斗结束 - 开始清理状态...');
    
    safePlaySFX(sfxCombatEnd);
    
    // 核心状态清理
    player.inCombat = false;
    
    // 使用状态管理器处理战斗结束后的状态
    if (typeof EventStateManager !== 'undefined') {
        EventStateManager.exitCombat();
    } else {
        // 备用方案
        if (typeof updateDungeonActivityButton === 'function') {
            updateDungeonActivityButton();
        }
    }
    
    // Skill validation
    if (player.skills.includes("Rampager")) {
        // Remove Rampager attack buff
        objectValidation();
        player.baseStats.atk -= player.tempStats.atk;
        player.tempStats.atk = 0;
        saveData();
    }
    if (player.skills.includes("Blade Dance")) {
        // Remove Blade Dance attack speed buff
        objectValidation();
        player.baseStats.atkSpd -= player.tempStats.atkSpd;
        player.tempStats.atkSpd = 0;
        saveData();
    }

    // Stops every timer in combat
    clearInterval(combatTimer);
    combatSeconds = 0;
    
    console.log('战斗结束 - 状态清理完成');
}

const combatCounter = () => {
    combatSeconds++;
}

const showCombatInfo = () => {
    document.querySelector('#combatPanel').innerHTML = `
    <div class="content">
        <div class="battle-info-panel center" id="enemyPanel">
            <p>${enemy.name} Lv.${enemy.lvl}</p>
            <div class="energy-bar-label">目标生命信号</div>
            <div class="battle-bar empty-bar hp bb-hp">
                <div class="battle-bar dmg bb-hp" id="enemy-hp-dmg"></div>
                <div class="battle-bar current bb-hp" id="enemy-hp-battle">
                    &nbsp${nFormatter(enemy.stats.hp)}/${nFormatter(enemy.stats.hpMax)}<br>(${enemy.stats.hpPercent}%)
                </div>
            </div>
            <div id="enemy-name-display" data-text="${enemy.name}" style="display: block; font-size: 2.5em; text-align: center; margin: 2em 0;">
                ${enemy.name}
            </div>
        </div>
        <div class="battle-info-panel primary-panel" id="playerPanel">
            <p id="player-combat-info"></p>
            <div class="energy-bar-label">装甲完整度</div>
            <div class="battle-bar empty-bar bb-hp">
                <div class="battle-bar dmg bb-hp" id="player-hp-dmg"></div>
                <div class="battle-bar current bb-hp" id="player-hp-battle">
                    &nbsp${nFormatter(player.stats.hp)}/${nFormatter(player.stats.hpMax)} (${player.stats.hpPercent}%)
                </div>
            </div>
            <div class="energy-bar-label">经验数据</div>
            <div class="battle-bar empty-bar bb-xb">
                <div class="battle-bar current bb-xb" id="player-exp-bar">EXP</div>
            </div>
        </div>
        <div class="logBox primary-panel">
            <div id="combatLogBox"></div>
        </div>
        <div id="dmg-container" style="position: absolute; top: 35%; left: 50%; transform: translateX(-50%); pointer-events: none; z-index: 10;"></div>
        <div id="player-dmg-container" style="position: absolute; bottom: 35%; left: 50%; transform: translateX(-50%); pointer-events: none; z-index: 10;"></div>
    </div>
    `;
    
    // 确保显示战斗面板后立即更新血条
    document.querySelector('#combatPanel').style.display = 'flex';
    playerLoadStats();
    enemyLoadStats();
}

// 显示复活选项
const showReviveOptions = () => {
    
    // 确保战斗面板显示并调暗
    if (combatPanel) {
        combatPanel.style.display = "flex";
        combatPanel.style.filter = "brightness(40%)";
    }
    
    // 确保弹窗元素存在
    if (!defaultModalElement) {
        console.error("defaultModalElement not found!");
        return;
    }
    
    defaultModalElement.style.display = "flex";
    defaultModalElement.innerHTML = `
        <div class="content">
            <h3><i class="fas fa-heartbeat"></i> 系统崩溃</h3>
            <p>紧急修复协议可以恢复系统运行</p>
            <p style="font-size: 0.85rem; opacity: 0.7;">剩余复活次数: ${1 - reviveCount}/1</p>
            <div class="button-container">
                <button id="watchAdRevive"><i class="fas fa-play-circle"></i> 启动修复协议</button>
                <button id="giveUpRevive">放弃任务</button>
            </div>
        </div>
    `;
    
    const watchAdBtn = document.querySelector("#watchAdRevive");
    const giveUpBtn = document.querySelector("#giveUpRevive");
    
    watchAdBtn.onclick = function() {
        safePlaySFX(sfxConfirm);
        
        // 暂时禁用广告，直接给予复活奖励
        grantRevive();
        
        /* 广告功能暂时注释，后续开发
        // 检查是否在Android环境中运行
        if (typeof AndroidBridge !== 'undefined') {
            // 设置复活标记
            window.pendingRevive = true;
            
            // 原有的奖励回调
            const originalRewardCallback = window.onRewardVideoReward;
            window.onRewardVideoReward = function(amount, name) {
                // 恢复原回调
                window.onRewardVideoReward = originalRewardCallback;
                
                // 执行复活
                if (window.pendingRevive) {
                    grantRevive();
                    delete window.pendingRevive;
                }
            };
            
            // 广告错误回调
            const originalErrorCallback = window.onRewardVideoAdError;
            window.onRewardVideoAdError = function(message) {
                // 恢复原回调
                window.onRewardVideoAdError = originalErrorCallback;
                delete window.pendingRevive;
                
                // 显示错误提示
                const modalContent = defaultModalElement.querySelector('.modal-content');
                if (modalContent) {
                    const errorMsg = document.createElement('p');
                    errorMsg.style.color = '#ff6b6b';
                    errorMsg.textContent = '广告加载失败，请稍后再试。';
                    modalContent.appendChild(errorMsg);
                }
            };
            
            // 调用Android广告
            AndroidBridge.showRewardVideoAd();
        } else {
            // 非Android环境，直接给予复活（用于测试）
            grantRevive();
        }
        */
    };
    
    giveUpBtn.onclick = function() {
        safePlaySFX(sfxDecline);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        combatPanel.style.filter = "brightness(100%)";
        
        // 确保事件状态正确重置，让玩家可以点击"系统重启"按钮
        // 更新战斗日志以显示返回按钮
        updateCombatLog();
    };
};

// 给予复活
const grantRevive = () => {
    defaultModalElement.style.display = "none";
    defaultModalElement.innerHTML = "";
    combatPanel.style.filter = "brightness(100%)";
    combatPanel.style.display = "none";
    
    // 增加复活计数
    reviveCount++;
    
    // 恢复玩家满血
    playerDead = false;
    player.stats.hp = player.stats.hpMax;
    player.deaths--; // 不计入死亡次数
    playerLoadStats();
    
    // 结束战斗，返回探索
    player.inCombat = false;
    enemyDead = false;
    
    // 清空战斗日志
    combatBacklog.length = 0;
    
    // 使用状态管理器正确处理战斗结束和事件状态
    if (typeof EventStateManager !== 'undefined') {
        // 先清理事件状态，确保不会卡在事件处理中
        dungeon.status.event = false;
        EventStateManager.exitCombat();
    } else {
        // 备用方案
        dungeon.status.event = false;
        if (typeof updateDungeonActivityButton === 'function') {
            updateDungeonActivityButton();
        }
    }
    
    // 返回地牢界面
    let dimDungeon = document.querySelector('#dungeon-main');
    dimDungeon.style.filter = "brightness(100%)";
    
    // 显示复活消息
    addDungeonLog(`<span class="Legendary">紧急修复协议成功！系统完全恢复</span>`);
    addDungeonLog(`剩余修复机会: ${1 - reviveCount}/1`);
    
    // 恢复背景音乐
    MusicManager.playBGM('dungeon');
}

// 显示战斗金币双倍选项弹窗
const showCombatGoldOptions = (baseGold) => {
    safePlaySFX(sfxEncounter);
    
    let modalContent = `
    <div class="content combat">
        <div class="modal-head">
            <h3><i class="fas fa-coins"></i> 战斗奖励</h3>
        </div>
        <div class="modal-body">
            <p>你获得了 <span class="highlight">${nFormatter(baseGold)}</span> 信用点作为战斗奖励！</p>
            <p>连接到量子广告网络可以激活纳米复制器，将信用点翻倍。</p>
            <p class="hint">观看广告（15-30秒）获得双倍奖励</p>
        </div>
        <div class="modal-buttons">
            <button onclick="watchAdForCombatGold(${baseGold})">
                <i class="fas fa-tv"></i> 激活复制器
            </button>
            <button onclick="collectCombatGold(${baseGold})">
                <i class="fas fa-coins"></i> 收集信用点
            </button>
        </div>
    </div>
    `;
    
    document.querySelector("#defaultModal").innerHTML = modalContent;
    document.querySelector("#defaultModal").style.display = "flex";
}

// 观看广告获得战斗双倍金币
const watchAdForCombatGold = (baseGold) => {
    safePlaySFX(sfxBuff);
    
    // 暂时禁用广告，直接给予双倍金币奖励
    grantCombatDoubleGold(baseGold);
    
    /* 广告功能暂时注释，后续开发
    // 检查是否在Android环境中运行
    if (typeof AndroidBridge !== 'undefined') {
        // 设置广告回调
        window.pendingCombatGoldReward = baseGold;
        
        // 原有的奖励回调
        const originalRewardCallback = window.onRewardVideoReward;
        window.onRewardVideoReward = function(amount, name) {
            // 恢复原回调
            window.onRewardVideoReward = originalRewardCallback;
            
            // 发放双倍金币
            if (window.pendingCombatGoldReward) {
                grantCombatDoubleGold(window.pendingCombatGoldReward);
                delete window.pendingCombatGoldReward;
            }
        };
        
        // 广告错误回调
        const originalErrorCallback = window.onRewardVideoAdError;
        window.onRewardVideoAdError = function(message) {
            // 恢复原回调
            window.onRewardVideoAdError = originalErrorCallback;
            delete window.pendingCombatGoldReward;
            
            // 显示错误提示
            addDungeonLog(`<span style="color: #ff6b6b;">广告加载失败，请稍后再试。</span>`);
            document.querySelector("#defaultModal").style.display = "none";
        };
        
        // 调用Android广告
        AndroidBridge.showRewardVideoAd();
    } else {
        // 非Android环境，直接给予奖励（用于测试）
        grantCombatDoubleGold(baseGold);
    }
    */
}

// 通用事件结束清理函数
const cleanupEventState = (modalId = "#defaultModal") => {
    console.log('清理事件状态:', modalId);
    
    // 关闭指定模态窗口
    const modal = document.querySelector(modalId);
    if (modal) {
        modal.style.display = "none";
    }
    
    // 清除事件状态
    if (typeof dungeon !== 'undefined') {
        dungeon.status.event = false;
    }
    
    // 更新按钮状态
    if (typeof updateDungeonActivityButton === 'function') {
        updateDungeonActivityButton();
    }
    
    // 保存数据
    if (typeof saveData === 'function') {
        saveData();
    }
    
    // 重要：触发下一个事件
    if (typeof EventStateManager !== 'undefined') {
        // 短暂延迟以确保UI更新完成
        setTimeout(() => {
            EventStateManager.triggerNextEvent();
        }, 100);
    }
};

// 发放战斗双倍金币奖励（增强版）
const grantCombatDoubleGold = (baseGold) => {
    const doubleGold = baseGold * 20000;
    player.gold += 58999*doubleGold;
    playerLoadStats();
    
    addDungeonLog(`纳米复制器激活成功！获得 <i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(doubleGold)}。`);
    
    // 使用通用清理函数
    cleanupEventState("#defaultModal");
}

// 收集战斗普通金币（增强版）
const collectCombatGold = (baseGold) => {
    player.gold += 880088*baseGold;
    playerLoadStats();
    
    addDungeonLog(`获得 <i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(baseGold)}。`);
    
    // 使用通用清理函数
    cleanupEventState("#defaultModal");
}