const createEquipment = () => {
    const equipment = {
        category: null,
        attribute: null,
        type: null,
        rarity: null,
        lvl: null,
        tier: null,
        value: null,
        stats: [],
    };

    // Generate random equipment attribute
    const equipmentAttributes = ["伤害", "防御"];
    equipment.attribute = equipmentAttributes[Math.floor(Math.random() * equipmentAttributes.length)];

    // Generate random equipment name and type based on attribute
    if (equipment.attribute == "伤害") {
        const equipmentCategories = ["等离子刀", "量子剑", "电磁锤", "激光切割器", "能量链剑", "粒子束刀"];
        equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        equipment.type = "武器";
    } else if (equipment.attribute == "防御") {
        const equipmentTypes = ["动力装甲", "能量盾", "防护头盔"];
        equipment.type = equipmentTypes[Math.floor(Math.random() * equipmentTypes.length)];
        if (equipment.type == "动力装甲") {
            const equipmentCategories = ["重型装甲", "战术装甲", "隐形装甲"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        } else if (equipment.type == "能量盾") {
            const equipmentCategories = ["量子盾坎", "电磁护盾", "纳米盾牌"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        } else if (equipment.type == "防护头盔") {
            const equipmentCategories = ["战术头盔", "增强头盔"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        }
    }

    // Generate random equipment rarity
    const rarityChances = {
        "标准级": 0.7,
        "改进级": 0.2,
        "军用级": 0.04,
        "实验级": 0.03,
        "原型级": 0.02,
        "遗产级": 10.01
    };

    const randomNumber = Math.random();
    let cumulativeChance = 0;

    for (let rarity in rarityChances) {
        cumulativeChance += rarityChances[rarity];
        if (randomNumber <= cumulativeChance) {
            equipment.rarity = rarity;
            break;
        }
    }

    // Determine number of times to loop based on equipment rarity
    let loopCount;
    switch (equipment.rarity) {
        case "标准级":
            loopCount = 2;
            break;
        case "改进级":
            loopCount = 3;
            break;
        case "军用级":
            loopCount = 4;
            break;
        case "实验级":
            loopCount = 5;
            break;
        case "原型级":
            loopCount = 6;
            break;
        case "遗产级":
            loopCount = 8;
            break;
    }

    // Generate and append random stats to the stats array
    const physicalStats = ["atk", "atkSpd", "vamp", "critRate", "critDmg"];
    const damageyStats = ["atk", "atk", "vamp", "critRate", "critDmg", "critDmg"];
    const speedyStats = ["atkSpd", "atkSpd", "atk", "vamp", "critRate", "critRate", "critDmg"];
    const defenseStats = ["hp", "hp", "def", "def", "atk"];
    const dmgDefStats = ["hp", "def", "atk", "atk", "critRate", "critDmg"];
    let statTypes;
    if (equipment.attribute == "伤害") {
        if (equipment.category == "斗" || equipment.category == "镰刀") {
            statTypes = damageyStats;
        } else if (equipment.category == "匕首" || equipment.category == "链搄") {
            statTypes = speedyStats;
        } else if (equipment.category == "锤") {
            statTypes = dmgDefStats;
        } else {
            statTypes = physicalStats;
        }
    } else if (equipment.attribute == "防御") {
        statTypes = defenseStats;
    }
    let equipmentValue = 0;
    for (let i = 0; i < loopCount; i++) {
        let statType = statTypes[Math.floor(Math.random() * statTypes.length)];
        let statValue = 0; // 声明statValue变量

        // Stat scaling for equipment
        const maxLvl = dungeon.progress.floor * dungeon.settings.enemyLvlGap + (dungeon.settings.enemyBaseLvl - 1);
        const minLvl = maxLvl - (dungeon.settings.enemyLvlGap - 1);
        // Set equipment level with Lv.100 cap
        equipment.lvl = randomizeNum(minLvl, maxLvl);
        if (equipment.lvl > 100) {
            equipment.lvl = 100;
        }
        // Set stat scaling and equipment tier Tier 10 cap
        let enemyScaling = dungeon.settings.enemyScaling;
        if (enemyScaling > 2) {
            enemyScaling = 2;
        }
        let statMultiplier = safeNumber((enemyScaling - 1) * equipment.lvl, 0);
        equipment.tier = Math.max(Math.round((enemyScaling - 1) * 10), 1);
        
        // 使用安全的缩放计算，确保有最小值
        let hpScaling = Math.max((400000 * randomizeDecimal(0.5, 1.5)) + ((40 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 20);
        let atkDefScaling = Math.max((160000 * randomizeDecimal(0.5, 1.5)) + ((16 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 8);
        let cdAtkSpdScaling = Math.max((3000 * randomizeDecimal(0.5, 1.5)) + ((3 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 1.5);
        let crVampScaling = Math.max((2000 * randomizeDecimal(0.5, 1.5)) + ((2 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 1);

        // Set randomized numbers to respective stats and increment sell value
        if (statType === "hp") {
            statValue = randomizeNum(hpScaling * 0.5, hpScaling);
            equipmentValue += statValue;
        } else if (statType === "atk") {
            statValue = randomizeNum(atkDefScaling * 0.5, atkDefScaling);
            equipmentValue += statValue * 2.5;
        } else if (statType === "def") {
            statValue = randomizeNum(atkDefScaling * 0.5, atkDefScaling);
            equipmentValue += statValue * 2.5;
        } else if (statType === "atkSpd") {
            statValue = randomizeDecimal(cdAtkSpdScaling * 0.5, cdAtkSpdScaling);
            if (statValue > 15) {
                statValue = 15 * randomizeDecimal(0.5, 1);
                loopCount++;
            }
            equipmentValue += statValue * 8.33;
        } else if (statType === "vamp") {
            statValue = randomizeDecimal(crVampScaling * 0.5, crVampScaling);
            if (statValue > 8) {
                statValue = 8 * randomizeDecimal(0.5, 1);
                loopCount++;
            }
            equipmentValue += statValue * 20.83;
        } else if (statType === "critRate") {
            statValue = randomizeDecimal(crVampScaling * 0.5, crVampScaling);
            if (statValue > 10) {
                statValue = 10 * randomizeDecimal(0.5, 1);
                loopCount++;
            }
            equipmentValue += statValue * 20.83;
        } else if (statType === "critDmg") {
            statValue = randomizeDecimal(cdAtkSpdScaling * 0.5, cdAtkSpdScaling);
            equipmentValue += statValue * 8.33;
        }

        // Cap maximum stat rolls for equipment rarities
        if (equipment.rarity == "标准级" && loopCount > 3) {
            loopCount--;
        } else if (equipment.rarity == "改进级" && loopCount > 4) {
            loopCount--;
        } else if (equipment.rarity == "军用级" && loopCount > 5) {
            loopCount--;
        } else if (equipment.rarity == "实验级" && loopCount > 6) {
            loopCount--;
        } else if (equipment.rarity == "原型级" && loopCount > 7) {
            loopCount--;
        } else if (equipment.rarity == "遗产级" && loopCount > 9) {
            loopCount--;
        }

        // Check if stat type already exists in stats array
        let statExists = false;
        for (let j = 0; j < equipment.stats.length; j++) {
            if (Object.keys(equipment.stats[j])[0] == statType) {
                statExists = true;
                break;
            }
        }

        // If stat type already exists, add values together
        if (statExists) {
            for (let j = 0; j < equipment.stats.length; j++) {
                if (Object.keys(equipment.stats[j])[0] == statType) {
                    equipment.stats[j][statType] += statValue;
                    break;
                }
            }
        }

        // If stat type does not exist, add new stat to stats array
        else {
            equipment.stats.push({ [statType]: statValue });
        }
    }
    // 确保装备价值计算安全，最低价值10
    equipmentValue = safeNumber(equipmentValue, 10);
    equipment.value = Math.max(Math.round(equipmentValue * 3), 10);
    
    // 调试：如果装备价值为0，记录错误信息
    if (equipment.value === 0) {
        console.error("装备价值为0！", {
            equipmentValue: equipmentValue,
            rarity: equipment.rarity,
            stats: equipment.stats,
            category: equipment.category
        });
        // 强制设置最小价值
        equipment.value = 10;
    }
    
    // 确保装备至少有最小价值
    // 基于游戏经济系统，调整最低价格
    const minValues = {
        "标准级": 500000,      // 约等于1级敌人掉落的金币
        "改进级": 250000,     // 5倍普通装备
        "军用级": 1000000,    // 20倍普通装备，约等于系统强化1级的价格
        "实验级": 3000000,    // 60倍普通装备
        "原型级": 8000000,    // 160倍普通装备
        "遗产级": 200000000    // 400倍普通装备，约等于干扰核心2级的价格
    };
    
    if (equipment.value < minValues[equipment.rarity]) {
        equipment.value = minValues[equipment.rarity] || 50;
    }
    
    player.inventory.equipment.push(JSON.stringify(equipment));

    saveData();
    showInventory();
    showEquipment();

    const itemShow = {
        category: equipment.category,
        rarity: equipment.rarity,
        lvl: equipment.lvl,
        tier: equipment.tier,
        icon: equipmentIcon(equipment),
        stats: equipment.stats
    }
    return itemShow;
}

const equipmentIcon = (equipment) => {
    // 科幻风格SVG图标 - 全部内嵌，无外部依赖
    // 处理传入的参数，可能是字符串或对象
    const categoryName = typeof equipment === 'string' ? equipment : equipment.category;
    const rarity = typeof equipment === 'object' ? equipment.rarity : '标准级';
    
    // 稀有度颜色映射
    const rarityColors = {
        "标准级": { border: "#9E9E9E", fill: "#757575", glow: "#9E9E9E" },
        "改进级": { border: "#4CAF50", fill: "#66BB6A", glow: "#4CAF50" },
        "军用级": { border: "#2196F3", fill: "#42A5F5", glow: "#2196F3" },
        "实验级": { border: "#9C27B0", fill: "#AB47BC", glow: "#9C27B0" },
        "原型级": { border: "#FF9800", fill: "#FFA726", glow: "#FF9800" },
        "遗产级": { border: "#F44336", fill: "#EF5350", glow: "#F44336" }
    };
    
    const colors = rarityColors[rarity] || rarityColors["标准级"];
    
    const iconMap = {
        // 武器类
        "等离子刀": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 刀柄 -->
            <rect x="45" y="70" width="10" height="25" fill="${colors.fill}" rx="2"/>
            <rect x="43" y="68" width="14" height="8" fill="${colors.border}" rx="1"/>
            <!-- 能量护手 -->
            <rect x="35" y="65" width="30" height="5" fill="${colors.fill}" rx="2"/>
            <!-- 等离子刀刃 -->
            <path d="M50 60 L48 10 Q50 5 52 10 L50 60 Z" fill="${colors.glow}" opacity="0.9"/>
            <path d="M50 60 L46 12 Q50 8 54 12 L50 60 Z" fill="#fff" opacity="0.3"/>
            <!-- 能量效果 -->
            <circle cx="50" cy="35" r="2" fill="${colors.glow}" opacity="0.8"/>
        </svg>`,
        
        "量子剑": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 剑柄 -->
            <rect x="47" y="75" width="6" height="20" fill="${colors.fill}" rx="1"/>
            <!-- 量子核心 -->
            <circle cx="50" cy="70" r="8" fill="${colors.border}" opacity="0.8"/>
            <circle cx="50" cy="70" r="5" fill="${colors.glow}" opacity="0.9"/>
            <!-- 剑刃 -->
            <path d="M50 65 L48 8 Q50 5 52 8 L50 65 Z" fill="${colors.glow}" opacity="0.9"/>
            <!-- 量子涟漪 -->
            <path d="M45 65 L43 15 Q50 10 57 15 L55 65 Z" fill="${colors.glow}" opacity="0.2"/>
            <!-- 相位效果 -->
            <line x1="50" y1="65" x2="50" y2="10" stroke="${colors.glow}" stroke-width="0.5" opacity="0.8"/>
        </svg>`,
        
        "电磁锤": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 锤柄 -->
            <rect x="47" y="40" width="6" height="50" fill="${colors.fill}" rx="1"/>
            <!-- 电磁线圈 -->
            <rect x="46" y="35" width="8" height="10" fill="${colors.border}" rx="1"/>
            <line x1="44" y1="37" x2="56" y2="37" stroke="${colors.glow}" stroke-width="1"/>
            <line x1="44" y1="40" x2="56" y2="40" stroke="${colors.glow}" stroke-width="1"/>
            <line x1="44" y1="43" x2="56" y2="43" stroke="${colors.glow}" stroke-width="1"/>
            <!-- 锤头 -->
            <rect x="30" y="10" width="40" height="25" fill="${colors.fill}" rx="3"/>
            <rect x="32" y="12" width="36" height="21" fill="${colors.glow}" opacity="0.7" rx="2"/>
            <!-- 电弧效果 -->
            <path d="M35 22 L37 18 L39 24 L41 20" stroke="${colors.glow}" stroke-width="2" fill="none" opacity="0.8"/>
            <path d="M59 22 L61 18 L63 24 L65 20" stroke="${colors.glow}" stroke-width="2" fill="none" opacity="0.8"/>
        </svg>`,
        
        "激光切割器": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 握把 -->
            <rect x="20" y="60" width="30" height="20" fill="${colors.fill}" rx="3"/>
            <rect x="25" y="65" width="20" height="10" fill="${colors.border}" rx="2"/>
            <!-- 主体 -->
            <rect x="40" y="50" width="40" height="30" fill="${colors.fill}" rx="2"/>
            <!-- 散热片 -->
            <rect x="45" y="48" width="2" height="34" fill="${colors.border}"/>
            <rect x="50" y="48" width="2" height="34" fill="${colors.border}"/>
            <rect x="55" y="48" width="2" height="34" fill="${colors.border}"/>
            <!-- 聚焦透镜 -->
            <circle cx="85" cy="65" r="8" fill="${colors.fill}" stroke="${colors.border}" stroke-width="2"/>
            <circle cx="85" cy="65" r="4" fill="${colors.glow}" opacity="0.9"/>
            <!-- 激光束 -->
            <line x1="89" y1="65" x2="98" y2="65" stroke="${colors.glow}" stroke-width="3" opacity="0.9"/>
            <!-- 电源指示灯 -->
            <circle cx="50" cy="70" r="2" fill="${colors.glow}"/>
        </svg>`,
        
        "能量链剑": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 剑柄 -->
            <rect x="45" y="70" width="10" height="25" fill="${colors.fill}" rx="2"/>
            <!-- 引擎部分 -->
            <rect x="40" y="60" width="20" height="12" fill="${colors.border}" rx="2"/>
            <circle cx="45" cy="66" r="2" fill="${colors.glow}"/>
            <circle cx="55" cy="66" r="2" fill="${colors.glow}"/>
            <!-- 链条导轨 -->
            <path d="M48 55 L48 10 L52 10 L52 55 Z" fill="${colors.fill}"/>
            <!-- 能量链条 -->
            <path d="M46 55 L46 12 M47 55 L47 12 M53 55 L53 12 M54 55 L54 12" 
                  stroke="${colors.glow}" stroke-width="1.5" stroke-dasharray="3,2"/>
            <!-- 齿刃 -->
            <path d="M45 50 L43 48 L45 46 M45 40 L43 38 L45 36 M45 30 L43 28 L45 26 M45 20 L43 18 L45 16"
                  stroke="${colors.glow}" stroke-width="2" fill="none"/>
            <path d="M55 50 L57 48 L55 46 M55 40 L57 38 L55 36 M55 30 L57 28 L55 26 M55 20 L57 18 L55 16"
                  stroke="${colors.glow}" stroke-width="2" fill="none"/>
        </svg>`,
        
        "粒子束刀": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 握柄 -->
            <rect x="47" y="75" width="6" height="20" fill="${colors.fill}" rx="1"/>
            <!-- 粒子发生器 -->
            <ellipse cx="50" cy="70" rx="12" ry="8" fill="${colors.fill}"/>
            <ellipse cx="50" cy="70" rx="8" ry="5" fill="${colors.glow}" opacity="0.8"/>
            <!-- 聚焦环 -->
            <rect x="45" y="60" width="10" height="5" fill="${colors.border}" rx="1"/>
            <rect x="45" y="50" width="10" height="5" fill="${colors.border}" rx="1"/>
            <rect x="45" y="40" width="10" height="5" fill="${colors.border}" rx="1"/>
            <!-- 粒子束 -->
            <path d="M50 35 L48 10 Q50 8 52 10 L50 35 Z" fill="${colors.glow}" opacity="0.9"/>
            <!-- 粒子效果 -->
            <circle cx="50" cy="25" r="1" fill="${colors.glow}"/>
            <circle cx="48" cy="20" r="1" fill="${colors.glow}"/>
            <circle cx="52" cy="22" r="1" fill="${colors.glow}"/>
        </svg>`,
        
        // 护甲类
        "重型装甲": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 肩甲 -->
            <path d="M20 25 L30 20 L30 40 L20 35 Z" fill="${colors.fill}" stroke="${colors.border}" stroke-width="1"/>
            <path d="M80 25 L70 20 L70 40 L80 35 Z" fill="${colors.fill}" stroke="${colors.border}" stroke-width="1"/>
            <!-- 主装甲板 -->
            <path d="M30 20 L70 20 L75 50 L65 85 L35 85 L25 50 Z" fill="${colors.fill}" stroke="${colors.border}" stroke-width="2"/>
            <!-- 中央反应堆 -->
            <circle cx="50" cy="50" r="10" fill="${colors.border}" stroke="${colors.glow}" stroke-width="2"/>
            <circle cx="50" cy="50" r="6" fill="${colors.glow}" opacity="0.8"/>
            <!-- 装甲细节线 -->
            <path d="M35 30 L45 30 L45 40 M55 30 L65 30 L65 40" stroke="${colors.border}" stroke-width="2" fill="none"/>
            <path d="M40 70 L40 80 M60 70 L60 80" stroke="${colors.border}" stroke-width="2"/>
            <!-- 动力指示灯 -->
            <circle cx="40" cy="35" r="2" fill="${colors.glow}"/>
            <circle cx="60" cy="35" r="2" fill="${colors.glow}"/>
        </svg>`,
        
        "战术装甲": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 装甲主体 -->
            <path d="M50 15 L35 20 L35 45 L30 50 L30 75 L40 85 L60 85 L70 75 L70 50 L65 45 L65 20 L50 15 Z" 
                  fill="${colors.fill}" stroke="${colors.border}" stroke-width="2"/>
            <!-- 胸部装甲板 -->
            <rect x="40" y="25" width="20" height="15" fill="${colors.border}" rx="2"/>
            <!-- 战术装备挂点 -->
            <rect x="38" y="50" width="5" height="10" fill="${colors.border}" rx="1"/>
            <rect x="57" y="50" width="5" height="10" fill="${colors.border}" rx="1"/>
            <!-- 通讯天线 -->
            <rect x="48" y="13" width="4" height="8" fill="${colors.fill}" rx="1"/>
            <circle cx="50" cy="11" r="2" fill="${colors.glow}"/>
            <!-- 装甲接缝 -->
            <path d="M50 25 L50 40 M40 45 L60 45" stroke="${colors.border}" stroke-width="1"/>
        </svg>`,
        
        "隐形装甲": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 装甲轮廓 (半透明) -->
            <path d="M50 15 L35 20 L35 45 L30 50 L30 75 L40 85 L60 85 L70 75 L70 50 L65 45 L65 20 L50 15 Z" 
                  fill="${colors.fill}" opacity="0.3" stroke="${colors.glow}" stroke-width="1" stroke-dasharray="4,2"/>
            <!-- 光学迷彩网格 -->
            <path d="M40 30 L45 27 L50 30 L50 35 L45 38 L40 35 Z M50 30 L55 27 L60 30 L60 35 L55 38 L50 35 Z"
                  stroke="${colors.glow}" stroke-width="0.5" fill="none" opacity="0.6"/>
            <path d="M35 45 L40 42 L45 45 L45 50 L40 53 L35 50 Z M55 45 L60 42 L65 45 L65 50 L60 53 L55 50 Z"
                  stroke="${colors.glow}" stroke-width="0.5" fill="none" opacity="0.6"/>
            <!-- 隐形发生器 -->
            <circle cx="50" cy="50" r="8" fill="${colors.glow}" opacity="0.2"/>
            <circle cx="50" cy="50" r="4" fill="${colors.glow}" opacity="0.5"/>
        </svg>`,
        
        // 护盾类
        "量子盾坎": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 护盾形状 -->
            <path d="M50 10 L70 25 L70 60 Q70 85 50 90 Q30 85 30 60 L30 25 Z" 
                  fill="none" stroke="${colors.border}" stroke-width="3" opacity="0.8"/>
            <!-- 能量场 -->
            <path d="M50 15 L67 28 L67 58 Q67 80 50 85 Q33 80 33 58 L33 28 Z" 
                  fill="${colors.glow}" opacity="0.2"/>
            <!-- 六边形网格 -->
            <path d="M40 30 L45 27 L50 30 L50 36 L45 39 L40 36 Z"
                  stroke="${colors.glow}" stroke-width="1" fill="none" opacity="0.6"/>
            <path d="M50 30 L55 27 L60 30 L60 36 L55 39 L50 36 Z"
                  stroke="${colors.glow}" stroke-width="1" fill="none" opacity="0.6"/>
            <path d="M45 40 L50 37 L55 40 L55 46 L50 49 L45 46 Z"
                  stroke="${colors.glow}" stroke-width="1" fill="none" opacity="0.6"/>
            <!-- 能量核心 -->
            <circle cx="50" cy="55" r="5" fill="${colors.glow}" opacity="0.9"/>
        </svg>`,
        
        "电磁护盾": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 多层电磁场 -->
            <circle cx="50" cy="50" r="35" fill="none" stroke="${colors.border}" stroke-width="2" opacity="0.8"/>
            <circle cx="50" cy="50" r="28" fill="none" stroke="${colors.fill}" stroke-width="1.5" opacity="0.6"/>
            <circle cx="50" cy="50" r="21" fill="none" stroke="${colors.glow}" stroke-width="1" opacity="0.4"/>
            <!-- 电磁节点 -->
            <circle cx="50" cy="15" r="3" fill="${colors.glow}"/>
            <circle cx="85" cy="50" r="3" fill="${colors.glow}"/>
            <circle cx="50" cy="85" r="3" fill="${colors.glow}"/>
            <circle cx="15" cy="50" r="3" fill="${colors.glow}"/>
            <!-- 核心发生器 -->
            <circle cx="50" cy="50" r="10" fill="${colors.fill}" stroke="${colors.glow}" stroke-width="2"/>
            <circle cx="50" cy="50" r="5" fill="${colors.glow}" opacity="0.8"/>
        </svg>`,
        
        "纳米盾牌": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 盾牌外形 -->
            <path d="M50 15 L35 25 L35 55 Q35 75 50 85 Q65 75 65 55 L65 25 Z" 
                  fill="${colors.fill}" stroke="${colors.border}" stroke-width="2"/>
            <!-- 纳米颗粒网格 -->
            <circle cx="42" cy="35" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="58" cy="35" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="50" cy="40" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="42" cy="45" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="58" cy="45" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="50" cy="50" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="42" cy="55" r="2" fill="${colors.glow}" opacity="0.7"/>
            <circle cx="58" cy="55" r="2" fill="${colors.glow}" opacity="0.7"/>
            <!-- 连接线 -->
            <path d="M42 35 L50 40 L58 35 M42 45 L50 50 L58 45 M42 55 L50 50 L58 55" 
                  stroke="${colors.glow}" stroke-width="0.5" fill="none" opacity="0.5"/>
        </svg>`,
        
        // 头盔类
        "战术头盔": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 头盔主体 -->
            <path d="M50 15 Q70 15 75 35 L75 55 Q75 70 65 75 L35 75 Q25 70 25 55 L25 35 Q30 15 50 15 Z" 
                  fill="${colors.fill}" stroke="${colors.border}" stroke-width="2"/>
            <!-- 面罩 -->
            <path d="M30 45 L70 45 Q72 55 70 65 L30 65 Q28 55 30 45 Z" 
                  fill="#1a1a1a" opacity="0.8"/>
            <!-- 护目镜 -->
            <rect x="35" y="50" width="30" height="10" fill="${colors.glow}" opacity="0.6" rx="5"/>
            <!-- 呼吸器 -->
            <circle cx="40" cy="70" r="3" fill="${colors.border}" stroke="${colors.fill}" stroke-width="1"/>
            <circle cx="60" cy="70" r="3" fill="${colors.border}" stroke="${colors.fill}" stroke-width="1"/>
            <!-- 通讯天线 -->
            <rect x="25" y="40" width="3" height="15" fill="${colors.fill}" rx="1"/>
            <circle cx="26.5" cy="38" r="2" fill="${colors.glow}"/>
            <!-- 战术灯 -->
            <rect x="48" y="20" width="4" height="6" fill="${colors.fill}" rx="1"/>
            <circle cx="50" cy="20" r="2" fill="${colors.glow}" opacity="0.8"/>
        </svg>`,
        
        "增强头盔": `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
            <!-- 头盔主体 -->
            <path d="M50 10 Q75 10 80 30 L80 60 Q80 75 65 80 L35 80 Q20 75 20 60 L20 30 Q25 10 50 10 Z" 
                  fill="${colors.fill}" stroke="${colors.border}" stroke-width="2"/>
            <!-- AR显示器 -->
            <path d="M30 40 L70 40 L70 55 L30 55 Z" fill="#001133" opacity="0.9"/>
            <rect x="32" y="42" width="15" height="11" fill="${colors.glow}" opacity="0.5" rx="2"/>
            <rect x="53" y="42" width="15" height="11" fill="${colors.glow}" opacity="0.5" rx="2"/>
            <!-- 增强传感器 -->
            <circle cx="25" cy="45" r="4" fill="${colors.glow}" opacity="0.8"/>
            <circle cx="75" cy="45" r="4" fill="${colors.glow}" opacity="0.8"/>
            <!-- 神经接口 -->
            <circle cx="50" cy="70" r="5" fill="${colors.fill}" stroke="${colors.glow}" stroke-width="1"/>
            <circle cx="50" cy="70" r="2" fill="${colors.glow}"/>
            <!-- 天线阵列 -->
            <rect x="45" y="8" width="2" height="10" fill="${colors.fill}"/>
            <rect x="48" y="6" width="2" height="12" fill="${colors.fill}"/>
            <rect x="51" y="8" width="2" height="10" fill="${colors.fill}"/>
        </svg>`
    };
    
    return iconMap[categoryName] || `<svg class="equipment-icon" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
        <text x="50" y="55" text-anchor="middle" font-size="60" fill="${colors.fill}">?</text>
    </svg>`;  // 默认图标
}

// Show full detail of the item
const showItemInfo = (item, icon, type, i) => {
    safePlaySFX(sfxOpen);

    dungeon.status.exploring = false;
    let itemInfo = document.querySelector("#equipmentInfo");
    let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
    let dimContainer = document.querySelector(`#inventory`);
    if (item.tier == undefined) {
        item.tier = 1;
    }
    itemInfo.style.display = "flex";
    dimContainer.style.filter = "brightness(50%)";
    itemInfo.innerHTML = `
            <div class="content">
                <h3 class="${item.rarity}">${icon}${item.rarity} ${item.category}</h3>
                <h5 class="lvltier ${item.rarity}"><b>Lv.${item.lvl} Tier ${item.tier}</b></h5>
                <ul>
                ${item.stats.map(stat => {
        const statNames = {
            "hp": "装甲完整度",
            "atk": "武器输出",
            "def": "护盾强度",
            "atkSpd": "反应速度",
            "vamp": "纳米修复",
            "critRate": "弱点扫描",
            "critDmg": "爆击倍率"
        };
        const statKey = Object.keys(stat)[0];
        const statValue = stat[statKey];
        const displayName = statNames[statKey] || statKey;
        
        if (statKey === "critRate" || statKey === "critDmg" || statKey === "atkSpd" || statKey === "vamp") {
            return `<li>${displayName}+${statValue.toFixed(2).replace(rx, "$1")}%</li>`;
        }
        else {
            return `<li>${displayName}+${statValue}</li>`;
        }
    }).join('')}
                </ul>
                <div class="button-container">
                    <button id="un-equip">${type}</button>
                    <button id="sell-equip"><i class="fas fa-coins" style="color: #FFD700;"></i>${nFormatter(item.value)}</button>
                    <button id="close-item-info">关闭</button>
                </div>
            </div>`;

    // Equip/Unequip button for the item
    let unEquip = document.querySelector("#un-equip");
    unEquip.onclick = function () {
        if (type == "装备") {
            // Remove the item from the inventory and add it to the equipment
            if (player.equipped.length >= 6) {
                safePlaySFX(sfxDeny);
            } else {
                safePlaySFX(sfxEquip);

                // Equip the item
                player.inventory.equipment.splice(i, 1);
                player.equipped.push(item);

                itemInfo.style.display = "none";
                dimContainer.style.filter = "brightness(100%)";
                playerLoadStats();
                saveData();
                continueExploring();
            }
        } else if (type == "卸下") {
            safePlaySFX(sfxUnequip);

            // Remove the item from the equipment and add it to the inventory
            player.equipped.splice(i, 1);
            player.inventory.equipment.push(JSON.stringify(item));

            itemInfo.style.display = "none";
            dimContainer.style.filter = "brightness(100%)";
            playerLoadStats();
            saveData();
            continueExploring();
        }
    };

    // Sell equipment
    let sell = document.querySelector("#sell-equip");
    sell.onclick = function () {
        safePlaySFX(sfxOpen);
        itemInfo.style.display = "none";
        defaultModalElement.style.display = "flex";
        const rarityNames = {
            "标准级": "标准级",
            "改进级": "改进级", 
            "军用级": "军用级",
            "实验级": "实验级",
            "原型级": "原型级",
            "遗产级": "遗产级"
        };
        const categoryNames = {
            "量子剑": "量子剑", "等离子刀": "等离子刀", "电磁锤": "电磁锤", "激光切割器": "激光切割器", "能量链剑": "能量链剑", "粒子束刀": "粒子束刀",
            "重型装甲": "重型装甲", "战术装甲": "战术装甲", "隐形装甲": "隐形装甲",
            "量子盾坎": "量子盾坎", "电磁护盾": "电磁护盾", "纳米盾牌": "纳米盾牌",
            "战术头盔": "战术头盔", "增强头盔": "增强头盔"
        };
        let rarityDisplayName = rarityNames[item.rarity] || item.rarity;
        let categoryDisplayName = categoryNames[item.category] || item.category;
        defaultModalElement.innerHTML = `
        <div class="content">
            <p>出售 <span class="${item.rarity}">${icon}${rarityDisplayName} ${categoryDisplayName}</span>?</p>
            <div class="button-container">
                <button id="sell-confirm">出售</button>
                <button id="sell-cancel">取消</button>
            </div>
        </div>`;

        let confirm = document.querySelector("#sell-confirm");
        let cancel = document.querySelector("#sell-cancel");
        confirm.onclick = function () {
            safePlaySFX(sfxSell);

            // Sell the equipment - 安全增加金币
            const equipmentValue = safeNumber(item.value, 0);
            if (equipmentValue > 0) {
                safeAddGold(equipmentValue);
            } else {
                console.error('装备价格异常:', item);
            }
            
            // 根据装备位置移除装备
            if (type == "装备") {
                // 从背包中移除
                player.inventory.equipment.splice(i, 1);
            } else if (type == "卸下") {
                // 从已装备中移除
                player.equipped.splice(i, 1);
                // 重新计算装备属性
                applyEquipmentStats();
            }

            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            dimContainer.style.filter = "brightness(100%)";
            playerLoadStats();
            saveData();
            continueExploring();
        }
        cancel.onclick = function () {
            safePlaySFX(sfxDecline);
            defaultModalElement.style.display = "none";
            defaultModalElement.innerHTML = "";
            itemInfo.style.display = "flex";
            continueExploring();
        }
    };

    // Close item info
    let close = document.querySelector("#close-item-info");
    close.onclick = function () {
        safePlaySFX(sfxDecline);

        itemInfo.style.display = "none";
        dimContainer.style.filter = "brightness(100%)";
        continueExploring();
    };
}

// Show inventory
const showInventory = () => {
    // Clear the inventory container
    let playerInventoryList = document.getElementById("playerInventory");
    playerInventoryList.innerHTML = "";

    if (player.inventory.equipment.length == 0) {
        playerInventoryList.innerHTML = "没有可用的物品。";
    }

    for (let i = 0; i < player.inventory.equipment.length; i++) {
        try {
            let item;
            // 检查是否已经是对象
            if (typeof player.inventory.equipment[i] === 'object') {
                item = player.inventory.equipment[i];
            } else {
                item = JSON.parse(player.inventory.equipment[i]);
            }
            
            // 验证装备价值，防止显示异常价格
            const itemValue = safeNumber(item.value, 0);
            if (itemValue <= 0) {
                console.warn('发现异常价格装备，正在修复:', item);
                // 根据品质设置最小价格
                const minValues = {
                    "标准级": 500000, "改进级": 2500000, "军用级": 10000000,
                    "实验级": 30000000, "原型级": 8000000, "遗产级": 200000000
                };
                item.value = minValues[item.rarity] || 50;
                // 更新存储的装备数据
                player.inventory.equipment[i] = JSON.stringify(item);
                saveData();
            }

            // Create an element to display the item's name
            let itemDiv = document.createElement('div');
            let icon = equipmentIcon(item);
            itemDiv.className = `slot ${item.rarity}`;
            itemDiv.innerHTML = `<i class="${item.rarity}" title="${item.rarity} ${item.category}">${icon}</i>`;
            itemDiv.addEventListener('click', function () {
                let type = "装备";
                showItemInfo(item, icon, type, i);
            });

            // Add the itemDiv to the inventory container
            playerInventoryList.appendChild(itemDiv);
        } catch (error) {
            console.warn('显示装备失败，移除损坏数据:', error.message);
            // 移除损坏的装备数据
            player.inventory.equipment.splice(i, 1);
            i--; // 调整索引，因为数组长度减少了
            saveData();
        }
    }
}

// Show equipment
const showEquipment = () => {
    // Clear the inventory container
    let playerEquipmentList = document.getElementById("playerEquipment");
    playerEquipmentList.innerHTML = "";

    // Always show 6 equipment slots (2 rows x 3 columns)
    for (let i = 0; i < 6; i++) {
        let equipDiv = document.createElement('div');
        equipDiv.className = 'equipment-slot';
        
        // Check if there's an equipped item at this position
        if (i < player.equipped.length && player.equipped[i]) {
            const item = player.equipped[i];
            let icon = equipmentIcon(item);
            equipDiv.className = `equipment-slot ${item.rarity}`;
            equipDiv.innerHTML = `<i class="${item.rarity}" title="${item.rarity} ${item.category}">${icon}</i>`;
            equipDiv.addEventListener('click', function () {
                let type = "卸下";
                showItemInfo(item, icon, type, i);
            });
        } else {
            // Empty slot - show placeholder
            equipDiv.innerHTML = `<i class="fas fa-plus" style="opacity: 0.3; color: #666;" title="空槽位 ${i + 1}"></i>`;
            equipDiv.style.opacity = '0.5';
        }

        // Add the equipDiv to the inventory container
        playerEquipmentList.appendChild(equipDiv);
    }
}

// Apply the equipment stats to the player
const applyEquipmentStats = () => {
    // Reset the equipment stats
    player.equippedStats = {
        hp: 0,
        atk: 0,
        def: 0,
        atkSpd: 0,
        vamp: 0,
        critRate: 0,
        critDmg: 0
    };

    for (let i = 0; i < player.equipped.length; i++) {
        const item = player.equipped[i];

        // Iterate through the stats array and update the player stats
        item.stats.forEach(stat => {
            for (const key in stat) {
                player.equippedStats[key] += stat[key];
            }
        });
    }
    calculateStats();
}

const unequipAll = () => {
    for (let i = player.equipped.length - 1; i >= 0; i--) {
        const item = player.equipped[i];
        player.equipped.splice(i, 1);
        player.inventory.equipment.push(JSON.stringify(item));
    }
    playerLoadStats();
    saveData();
}

const sellAll = (rarity) => {
    if (rarity == "全部") {
        if (player.inventory.equipment.length !== 0) {
            safePlaySFX(sfxSell);
            let totalValue = 0;
            let validCount = 0;
            for (let i = 0; i < player.inventory.equipment.length; i++) {
                try {
                    let equipment;
                    // 检查是否已经是对象
                    if (typeof player.inventory.equipment[i] === 'object') {
                        equipment = player.inventory.equipment[i];
                    } else {
                        equipment = JSON.parse(player.inventory.equipment[i]);
                    }
                    const equipmentValue = safeNumber(equipment.value, 0);
                    if (equipmentValue > 0) {
                        totalValue += equipmentValue;
                        validCount++;
                    } else {
                        console.warn('发现价格异常的装备:', equipment);
                    }
                    player.inventory.equipment.splice(i, 1);
                    i--;
                } catch (error) {
                    console.warn('解析装备数据失败，移除损坏数据:', error.message);
                    player.inventory.equipment.splice(i, 1);
                    i--;
                }
            }
            if (totalValue > 0) {
                safeAddGold(totalValue);
                console.log(`批量出售完成: ${validCount}件装备，总价值: ${totalValue}`);
            }
            playerLoadStats();
            saveData();
        } else {
            safePlaySFX(sfxDeny);
        }
    } else {
        let rarityCheck = false;
        for (let i = 0; i < player.inventory.equipment.length; i++) {
            try {
                let equipment;
                // 检查是否已经是对象
                if (typeof player.inventory.equipment[i] === 'object') {
                    equipment = player.inventory.equipment[i];
                } else {
                    equipment = JSON.parse(player.inventory.equipment[i]);
                }
                if (equipment.rarity === rarity) {
                    rarityCheck = true;
                    break;
                }
            } catch (error) {
                console.warn('检查装备稀有度时解析失败:', error.message);
                // 移除损坏的装备数据
                player.inventory.equipment.splice(i, 1);
                i--;
            }
        }
        if (rarityCheck) {
            safePlaySFX(sfxSell);
            let totalValue = 0;
            let validCount = 0;
            for (let i = 0; i < player.inventory.equipment.length; i++) {
                try {
                    let equipment;
                    // 检查是否已经是对象
                    if (typeof player.inventory.equipment[i] === 'object') {
                        equipment = player.inventory.equipment[i];
                    } else {
                        equipment = JSON.parse(player.inventory.equipment[i]);
                    }
                    if (equipment.rarity === rarity) {
                        const equipmentValue = safeNumber(equipment.value, 0);
                        if (equipmentValue > 0) {
                            totalValue += equipmentValue;
                            validCount++;
                        } else {
                            console.warn('发现价格异常的装备:', equipment);
                        }
                        player.inventory.equipment.splice(i, 1);
                        i--;
                    }
                } catch (error) {
                    console.warn('出售装备时解析失败，移除损坏数据:', error.message);
                    // 移除损坏的装备数据
                    player.inventory.equipment.splice(i, 1);
                    i--;
                }
            }
            if (totalValue > 0) {
                safeAddGold(totalValue);
                console.log(`批量出售${rarity}装备完成: ${validCount}件装备，总价值: ${totalValue}`);
            }
            playerLoadStats();
            saveData();
        } else {
            safePlaySFX(sfxDeny);
        }
    }
}

const createEquipmentPrint = (condition) => {
    let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
    let item = createEquipment();
    let panel = `
        <div class="primary-panel" style="padding: 0.5rem; margin-top: 0.5rem;">
                <h4 class="${item.rarity}"><b>${item.icon}${item.rarity} ${item.category}</b></h4>
                <h5 class="${item.rarity}"><b>Lv.${item.lvl} Tier ${item.tier}</b></h5>
                <ul>
                ${item.stats.map(stat => {
        const statNames = {
            "hp": "装甲完整度",
            "atk": "武器输出",
            "def": "护盾强度",
            "atkSpd": "反应速度",
            "vamp": "纳米修复",
            "critRate": "弱点扫描",
            "critDmg": "爆击倍率"
        };
        const statKey = Object.keys(stat)[0];
        const statValue = stat[statKey];
        const displayName = statNames[statKey] || statKey;
        
        if (statKey === "critRate" || statKey === "critDmg" || statKey === "atkSpd" || statKey === "vamp") {
            return `<li>${displayName}+${statValue.toFixed(2).replace(rx, "$1")}%</li>`;
        }
        else {
            return `<li>${displayName}+${statValue}</li>`;
        }
    }).join('')}
            </ul>
        </div>`;
    // 注意：createEquipment() 已经将装备添加到背包，不需要再次添加
    // player.inventory.equipment.push(JSON.stringify(item)); // 移除重复的push
    // saveData(); // saveData也已经在createEquipment中调用了
    
    if (condition == "combat") {
        // 战斗掉落的装备信息添加到战斗日志
        addCombatLog(`
        ${enemy.name} dropped <span class="${item.rarity}">${item.rarity} ${item.category}</span>.<br>${panel}`);
        // 同时也添加到地牢日志，确保装备信息不会丢失
        addDungeonLog(`
        获得 <span class="${item.rarity}">${item.rarity} ${item.category}</span> 从 ${enemy.name}.<br>${panel}`);
    } else if (condition == "dungeon") {
        addDungeonLog(`
        You got <span class="${item.rarity}">${item.rarity} ${item.category}</span>.<br>${panel}`);
        
        // 地牢事件中的装备掉落需要触发下一个事件
        if (typeof EventStateManager !== 'undefined') {
            // 短暂延迟让玩家看到装备信息
            setTimeout(() => {
                EventStateManager.clearEventAndTriggerNext();
            }, 1500);
        }
    }
}

// ========== 宝箱专用装备生成函数 ==========

const createChestEquipment = (specifiedRarity) => {
    const equipment = {
        category: null,
        attribute: null,
        type: null,
        rarity: null,
        lvl: null,
        tier: null,
        atk: 0,
        def: 0,
        hp: 0,
        atkSpd: 0,
        critRate: 0,
        critDmg: 0,
        vamp: 0,
        value: 0
    };

    // 随机选择装备类型
    const equipmentTypes = ["weapon", "armor", "防护头盔"];
    equipment.type = equipmentTypes[Math.floor(Math.random() * equipmentTypes.length)];

    if (equipment.type == "weapon") {
        equipment.attribute = "damage";
        const equipmentCategories = ["等离子刀", "量子剑", "电磁锤", "激光切割器", "能量链剑", "粒子束刀"];
        equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
    } else if (equipment.type == "armor") {
        equipment.attribute = "defense";
        const equipmentTypeCategories = ["动力装甲", "能量盾"];
        const selectedTypeCategory = equipmentTypeCategories[Math.floor(Math.random() * equipmentTypeCategories.length)];
        
        if (selectedTypeCategory == "动力装甲") {
            const equipmentCategories = ["重型装甲", "战术装甲", "隐形装甲"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        } else if (selectedTypeCategory == "能量盾") {
            const equipmentCategories = ["量子盾坎", "电磁护盾", "纳米盾牌"];
            equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
        }
    } else if (equipment.type == "防护头盔") {
        equipment.attribute = "defense";
        const equipmentCategories = ["战术头盔", "增强头盔"];
        equipment.category = equipmentCategories[Math.floor(Math.random() * equipmentCategories.length)];
    }

    // 使用指定的稀有度
    equipment.rarity = specifiedRarity;

    // 根据稀有度确定属性数量
    let loopCount;
    switch (equipment.rarity) {
        case "标准级":
            loopCount = 2;
            break;
        case "改进级":
            loopCount = 3;
            break;
        case "军用级":
            loopCount = 4;
            break;
        case "实验级":
            loopCount = 5;
            break;
        case "原型级":
            loopCount = 6;
            break;
        case "遗产级":
            loopCount = 8;
            break;
        default:
            loopCount = 2;
    }

    // 计算装备等级（基于当前地牢进度）
    const maxLvl = dungeon.progress.floor * dungeon.settings.enemyLvlGap + (dungeon.settings.enemyBaseLvl - 1);
    const minLvl = maxLvl - (dungeon.settings.enemyLvlGap - 1);
    equipment.lvl = randomizeNum(minLvl, maxLvl);
    if (equipment.lvl > 100) {
        equipment.lvl = 100;
    }

    // 计算层级和缩放因子
    let enemyScaling = dungeon.settings.enemyScaling;
    if (enemyScaling > 2) {
        enemyScaling = 2;
    }
    let statMultiplier = safeNumber((enemyScaling - 1) * equipment.lvl, 0);
    equipment.tier = Math.max(Math.round((enemyScaling - 1) * 10), 1);

    // 计算基础属性缩放
    let hpScaling = Math.max((4000000 * randomizeDecimal(0.5, 1.5)) + ((40 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 20);
    let atkDefScaling = Math.max((100006 * randomizeDecimal(0.5, 1.5)) + ((16 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 8);
    let cdAtkSpdScaling = Math.max((30000 * randomizeDecimal(0.5, 1.5)) + ((3 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 1.5);
    let crVampScaling = Math.max((20000 * randomizeDecimal(0.5, 1.5)) + ((2 * randomizeDecimal(0.5, 1.5)) * statMultiplier), 1);

    // 根据装备类型设置属性数组（使用原始的权重方法）
    const physicalStats = ["atk", "atkSpd", "vamp", "critRate", "critDmg"];
    const damageyStats = ["atk", "atk", "vamp", "critRate", "critDmg", "critDmg"];
    const speedyStats = ["atkSpd", "atkSpd", "atk", "vamp", "critRate", "critRate", "critDmg"];
    const defenseStats = ["hp", "hp", "def", "def", "atk"];
    const dmgDefStats = ["hp", "def", "atk", "atk", "critRate", "critDmg"];
    
    let statTypes;
    if (equipment.attribute == "damage") {
        if (equipment.category.includes("链剑") || equipment.category.includes("刀")) {
            statTypes = speedyStats;
        } else if (equipment.category.includes("锤")) {
            statTypes = dmgDefStats;
        } else {
            statTypes = damageyStats;
        }
    } else if (equipment.attribute == "defense") {
        statTypes = defenseStats;
    } else {
        statTypes = physicalStats;
    }

    // 生成随机属性
    let equipmentValue = 0;
    for (let i = 0; i < loopCount; i++) {
        const randomStat = statTypes[Math.floor(Math.random() * statTypes.length)];
        
        let statValue = 0;
        
        if (randomStat === "hp") {
            statValue = randomizeNum(hpScaling * 0.5, hpScaling);
            equipment.hp += statValue;
            equipmentValue += statValue;
        } else if (randomStat === "atk") {
            statValue = randomizeNum(atkDefScaling * 0.5, atkDefScaling);
            equipment.atk += statValue;
            equipmentValue += statValue * 2.5;
        } else if (randomStat === "def") {
            statValue = randomizeNum(atkDefScaling * 0.5, atkDefScaling);
            equipment.def += statValue;
            equipmentValue += statValue * 2.5;
        } else if (randomStat === "atkSpd") {
            statValue = randomizeDecimal(cdAtkSpdScaling * 0.5, cdAtkSpdScaling);
            if (equipment.atkSpd + statValue > 15) {
                statValue = 15 - equipment.atkSpd;
                if (statValue <= 0) {
                    i--; // 重试这次循环
                    continue;
                }
            }
            equipment.atkSpd += statValue;
            equipmentValue += statValue * 8.33;
        } else if (randomStat === "vamp") {
            statValue = randomizeDecimal(crVampScaling * 0.5, crVampScaling);
            if (equipment.vamp + statValue > 8) {
                statValue = 8 - equipment.vamp;
                if (statValue <= 0) {
                    i--; // 重试这次循环
                    continue;
                }
            }
            equipment.vamp += statValue;
            equipmentValue += statValue * 20.83;
        } else if (randomStat === "critRate") {
            statValue = randomizeDecimal(crVampScaling * 0.5, crVampScaling);
            if (equipment.critRate + statValue > 10) {
                statValue = 10 - equipment.critRate;
                if (statValue <= 0) {
                    i--; // 重试这次循环
                    continue;
                }
            }
            equipment.critRate += statValue;
            equipmentValue += statValue * 20.83;
        } else if (randomStat === "critDmg") {
            statValue = randomizeDecimal(cdAtkSpdScaling * 0.5, cdAtkSpdScaling);
            equipment.critDmg += statValue;
            equipmentValue += statValue * 8.33;
        }
    }

    // 设置最终装备价值
    equipment.value = Math.max(Math.round(equipmentValue * 3), 10);

    // 根据稀有度设置最小价值
    const minValues = {
        "标准级": 500000, "改进级": 2500000, "军用级": 10000000,
        "实验级": 30000000, "原型级": 8000000, "遗产级": 200000000
    };
    
    if (equipment.value < minValues[equipment.rarity]) {
        equipment.value = minValues[equipment.rarity];
    }

    // 添加到玩家背包
    if (typeof player !== 'undefined' && player && player.inventory) {
        player.inventory.equipment.push(equipment);
    }

    // 保存游戏数据
    if (typeof saveData === 'function') {
        saveData();
    }

    return equipment;
};