let player = JSON.parse(localStorage.getItem("playerData"));
let leveled = false;

// 装备稀有度迁移函数
// 获取升级词条信息
const getUpgradeInfo = (statType, value) => {
    // 根据数值直接判定等级
    let tier = 1;
    
    // 每个属性的等级阈值
    const tierThresholds = {
        "hp": [10, 20, 35, 55, 80],        // 标准→改进→军用→实验→原型→遗产
        "atk": [6, 10, 15, 22, 30],
        "def": [6, 10, 15, 22, 30],
        "atkSpd": [2, 4, 6, 9, 12],
        "vamp": [0.5, 1, 1.5, 2.5, 3.5],
        "critRate": [1, 2, 3, 4.5, 6],
        "critDmg": [5, 8, 12, 18, 25]
    };
    
    const thresholds = tierThresholds[statType];
    
    // 判定等级
    if (value >= thresholds[4]) tier = 6;        // 遗产级（红色）
    else if (value >= thresholds[3]) tier = 5;   // 原型级（橙色）
    else if (value >= thresholds[2]) tier = 4;   // 实验级（紫色）
    else if (value >= thresholds[1]) tier = 3;   // 军用级（蓝色）
    else if (value >= thresholds[0]) tier = 2;   // 改进级（绿色）
    // else tier = 1;                             // 标准级（灰色）
    
    // 词条名称 - 每种属性一个固定名称
    const upgradeNames = {
        "hp": "装甲强化",
        "atk": "武器增幅",
        "def": "护盾增强",
        "atkSpd": "反应加速",
        "vamp": "纳米修复",
        "critRate": "弱点扫描",
        "critDmg": "爆击强化"
    };
    
    const unitSuffix = {
        "hp": " 点装甲值",
        "atk": "% 伤害",
        "def": "% 防御", 
        "atkSpd": "% 攻击速度",
        "vamp": "% 修复效率",
        "critRate": "% 扫描精度",
        "critDmg": "% 爆击伤害"
    };
    
    return {
        title: upgradeNames[statType],
        description: `提升 ${value}${unitSuffix[statType] || '%'}`,
        tierClass: `upgrade-tier-${tier}`
    };
};

const migrateEquipmentRarity = () => {
    const rarityMap = {
        "普通": "标准级",
        "优秀": "改进级",
        "稀有": "军用级",
        "史诗": "实验级",
        "传说": "原型级",
        "传承": "遗产级"
    };
    
    let migrated = false;
    
    // 迁移背包中的装备
    if (player && player.inventory && player.inventory.equipment) {
        for (let i = 0; i < player.inventory.equipment.length; i++) {
            try {
                let item;
                // 检查是否已经是对象
                if (typeof player.inventory.equipment[i] === 'object') {
                    item = player.inventory.equipment[i];
                } else {
                    item = JSON.parse(player.inventory.equipment[i]);
                }
                
                // 检查是否需要迁移
                if (rarityMap[item.rarity]) {
                    item.rarity = rarityMap[item.rarity];
                    // 保存回去
                    player.inventory.equipment[i] = JSON.stringify(item);
                    migrated = true;
                }
            } catch (e) {
                console.error('迁移装备失败:', e);
            }
        }
    }
    
    // 迁移已装备的装备
    if (player && player.equipped) {
        for (let i = 0; i < player.equipped.length; i++) {
            try {
                let item;
                // 检查是否已经是对象
                if (typeof player.equipped[i] === 'object') {
                    item = player.equipped[i];
                } else {
                    item = JSON.parse(player.equipped[i]);
                }
                
                // 检查是否需要迁移
                if (rarityMap[item.rarity]) {
                    item.rarity = rarityMap[item.rarity];
                    // 保存回去
                    player.equipped[i] = JSON.stringify(item);
                    migrated = true;
                }
            } catch (e) {
                console.error('迁移已装备装备失败:', e);
            }
        }
    }
    
    if (migrated) {
        console.log('装备稀有度迁移完成');
        saveData();
    }
};

// 执行迁移
if (player) {
    migrateEquipmentRarity();
}

// ========== Player Functions ==========
// Set the initial player stats
const playerInitialStats = (name, skill1, skill2) => {
    player = {
        name: name,
        lvl: 1,
        exp: { expCurr: 0, expMax: 250, expCurrLvl: 0, expMaxLvl: 250, lvlGained: 0 },
        gold: 0,
        kills: 0,
        deaths: 0,
        baseStats: {
            hpMax: 100,
            hp: 100,
            atk: 10,
            def: 5,
            atkSpd: 0.6,
            vamp: 0,
            critRate: 0,
            critDmg: 50
        },
        tempStats: { atk: 0, atkSpd: 0 },
        equippedStats: { hp: 0, atk: 0, def: 0, atkSpd: 0, vamp: 0, critRate: 0, critDmg: 0 },
        bonusStats: { hp: 0, atk: 0, def: 0, atkSpd: 0, vamp: 0, critRate: 0, critDmg: 0 },
        stats: {
            hpMax: 100,
            hp: 100,
            atk: 10,
            def: 5,
            atkSpd: 0.6,
            vamp: 0,
            critRate: 0,
            critDmg: 50
        },
        inventory: { consumables: [], equipment: [] },
        equipped: [],
        skills: [skill1, skill2],
        blessing: 1,
        playtime: 0,
        inCombat: false,
        timedBuffs: {} // 添加限时增益系统
    };
    applySkillStats();
    applyEquipmentStats();
}

// Apply skill bonuses on player stats
const applySkillStats = () => {
    if (player.skills.includes("Devastator")) {
        // Increase base attack by 30% but lower base attack speed by 30%
        player.baseStats.atk = Math.round(player.baseStats.atk + ((30 * player.baseStats.atk) / 100));
        player.baseStats.atkSpd = (player.baseStats.atkSpd - ((30 * player.baseStats.atkSpd) / 100));
    }
    if (player.skills.includes("Berserker")) {
        // Start with 10% critical rate
        player.baseStats.critRate = 10;
    }
    if (player.skills.includes("Bloodthirster")) {
        // Start with 5% life steal
        player.baseStats.vamp = 5;
    }
    if (player.skills.includes("Tank")) {
        // Start with extra 100 health and 10 defense
        player.baseStats.hpMax += 100;
        player.baseStats.hp += 100;
        player.baseStats.def += 10;
    }
    if (player.skills.includes("Gambler")) {
        // Start with 5% critical rate and 50% critical damage
        player.baseStats.critRate += 5;
        player.baseStats.critDmg += 50;
    }
}

// ========== Generates the Player's Stats UI ==========
const playerLoadStats = () => {
    showEquipment();
    showInventory();
    applyEquipmentStats();

    let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
    if (player.stats.hp > player.stats.hpMax) {
        player.stats.hp = player.stats.hpMax;
    }
    player.stats.hpPercent = Number((player.stats.hp / player.stats.hpMax) * 100).toFixed(2).replace(rx, "$1");
    player.exp.expPercent = Number((player.exp.expCurrLvl / player.exp.expMaxLvl) * 100).toFixed(2).replace(rx, "$1");

    // Generate battle info for player if in combat
    if (player.inCombat || (typeof playerDead !== 'undefined' && playerDead)) {
        const playerCombatHpElement = document.querySelector('#player-hp-battle');
        const playerHpDamageElement = document.querySelector('#player-hp-dmg');
        const playerExpElement = document.querySelector('#player-exp-bar');
        const playerInfoElement = document.querySelector('#player-combat-info');
        
        if (playerCombatHpElement) {
            playerCombatHpElement.innerHTML = `&nbsp${nFormatter(player.stats.hp)}/${nFormatter(player.stats.hpMax)} (${player.stats.hpPercent}%)`;
            playerCombatHpElement.style.width = `${player.stats.hpPercent}%`;
        }
        
        if (playerHpDamageElement) {
            playerHpDamageElement.style.width = `${player.stats.hpPercent}%`;
        }
        
        if (playerExpElement) {
            playerExpElement.style.width = `${player.exp.expPercent}%`;
        }
        
        if (playerInfoElement) {
            playerInfoElement.innerHTML = `${player.name} Lv.${player.lvl} (${player.exp.expPercent}%)`;
        }
    }

    // Header
    document.querySelector("#player-name").innerHTML = `${player.name} Lv.${player.lvl}`;
    document.querySelector("#player-exp").innerHTML = `<i class="fas fa-chart-line"></i> ${player.exp.expPercent}%`;
    
    // 确保金币显示安全
    const goldAmount = safeNumber(player.gold, 0);
    const goldDisplay = nFormatter(goldAmount);
    document.querySelector("#player-gold").innerHTML = `<i class="fas fa-coins" style="color: #FFD700;"></i> ${goldDisplay}`;
    
    // 调试信息
    if (goldAmount !== player.gold) {
        console.warn('金币数值异常，已修正:', player.gold, '→', goldAmount);
        player.gold = goldAmount;
    }

    // Player Stats (without buff indicators, buffs shown in bonus stats section)
    playerHpElement.innerHTML = `${nFormatter(player.stats.hp)}/${nFormatter(player.stats.hpMax)} (${player.stats.hpPercent}%)`;
    playerAtkElement.innerHTML = nFormatter(player.stats.atk);
    playerDefElement.innerHTML = nFormatter(player.stats.def);
    playerAtkSpdElement.innerHTML = player.stats.atkSpd.toFixed(2).replace(rx, "$1");
    playerVampElement.innerHTML = (player.stats.vamp).toFixed(2).replace(rx, "$1");
    playerCrateElement.innerHTML = (player.stats.critRate).toFixed(2).replace(rx, "$1");
    playerCdmgElement.innerHTML = (player.stats.critDmg).toFixed(2).replace(rx, "$1");

    // Player Bonus Stats with temporary buffs
    document.querySelector("#bonus-stats").innerHTML = `
    <h4>系统增强</h4>
    <p><i class="fas fa-heart"></i>装甲强度+${player.bonusStats.hp.toFixed(2).replace(rx, "$1")}%${getTempBuffText('hp')}</p>
    <p><i class="ra ra-sword"></i>武器功率+${player.bonusStats.atk.toFixed(2).replace(rx, "$1")}%${getTempBuffText('atk')}</p>
    <p><i class="ra ra-round-shield"></i>护盾能量+${player.bonusStats.def.toFixed(2).replace(rx, "$1")}%${getTempBuffText('def')}</p>
    <p><i class="ra ra-plain-dagger"></i>反应提升+${player.bonusStats.atkSpd.toFixed(2).replace(rx, "$1")}%${getTempBuffText('atkSpd')}</p>
    <p><i class="ra ra-dripping-blade"></i>修复效率+${player.bonusStats.vamp.toFixed(2).replace(rx, "$1")}%${getTempBuffText('vamp')}</p>
    <p><i class="ra ra-lightning-bolt"></i>扫描精度+${player.bonusStats.critRate.toFixed(2).replace(rx, "$1")}%${getTempBuffText('critRate')}</p>
    <p><i class="ra ra-focused-lightning"></i>爆击增幅+${player.bonusStats.critDmg.toFixed(2).replace(rx, "$1")}%${getTempBuffText('critDmg')}</p>`;
    
}

// 获取临时增益显示文本
const getTempBuffText = (statType) => {
    const activeBuff = getActiveBuffForStat(statType);
    if (!activeBuff) return '';
    
    // timedBuffs存储的是增益值，如0.3表示30%
    const percentage = (activeBuff.value * 100).toFixed(0);
    const timeLeft = formatRemainingTime(activeBuff.endTime);
    
    // 调试输出
    console.log(`显示临时增益: ${statType}, 增益值: ${activeBuff.value}, 百分比: ${percentage}%`);
    
    // 如果百分比为0，不显示
    if (percentage === '0') {
        return '';
    }
    
    return ` <span class="temp-buff-text">+${percentage}% (${timeLeft})</span>`;
};

// 格式化剩余时间
const formatRemainingTime = (endTime) => {
    const remaining = endTime - Date.now();
    if (remaining <= 0) return "已过期";
    
    const minutes = Math.floor(remaining / 60000);
    const seconds = Math.floor((remaining % 60000) / 1000);
    
    if (minutes > 0) {
        return `${minutes}分${seconds}秒`;
    } else {
        return `${seconds}秒`;
    }
};

// 获取某个属性的激活增益
const getActiveBuffForStat = (statType) => {
    if (!player.timedBuffs || !player.timedBuffs[statType]) {
        return null;
    }
    
    const buff = player.timedBuffs[statType];
    if (Date.now() >= buff.endTime) {
        // 增益已过期，清理它
        delete player.timedBuffs[statType];
        return null;
    }
    
    return buff;
};

// 启动限时增益定时器
let buffTimerInterval = null;
const startTimedBuffTimer = () => {
    // 清除已有的定时器
    if (buffTimerInterval) {
        clearInterval(buffTimerInterval);
    }
    
    // 每秒更新一次显示
    buffTimerInterval = setInterval(() => {
        // 检查是否还有激活的增益
        let hasActiveBuff = false;
        if (player.timedBuffs) {
            for (let stat in player.timedBuffs) {
                if (Date.now() < player.timedBuffs[stat].endTime) {
                    hasActiveBuff = true;
                    break;
                }
            }
        }
        
        // 如果有激活的增益，更新显示
        if (hasActiveBuff) {
            playerLoadStats();
        } else {
            // 没有激活的增益，停止定时器
            clearInterval(buffTimerInterval);
            buffTimerInterval = null;
        }
    }, 1000);
};

// Gain Exp per kill
const playerExpGain = () => {
    player.exp.expCurr += enemy.rewards.exp;
    player.exp.expCurrLvl += enemy.rewards.exp;
    
    if (player.exp.expCurrLvl >= player.exp.expMaxLvl) {
        leveled = true; // 设置升级标志
        
        // 升级判定 - 支持多级连升
        while (player.exp.expCurrLvl >= player.exp.expMaxLvl) {
            player.lvl++;
            dungeon.statistics.lvlGained++;
            player.exp.lvlGained++;
            player.exp.expCurrLvl -= player.exp.expMaxLvl;
            // 经验递增公式：每级增加10%，再加100点基础值
            let newExpMax = Math.round(player.exp.expMaxLvl * 1.1 + 100);
            // 100级后固定经验值
            if (player.lvl >= 100) {
                newExpMax = 1000000;
            }
            player.exp.expMaxLvl = newExpMax;
            player.exp.expMax = newExpMax;
        }
        
        // 升级后恢复满血（放在循环外，只执行一次）
        player.stats.hp = player.stats.hpMax;
        
        // 播放升级音效（只播放一次）
        if (typeof sfxBuff !== 'undefined' && sfxBuff.play) {
            safePlaySFX(sfxBuff);
        }
    }
    
    if (leveled) {
        lvlupPopup();
    }
    
    saveData();
}

// applyEquipmentStats 函数已经在 equipment.js 中定义

// Shows the level up popup
const lvlupPopup = () => {
    // 确保DOM元素存在
    const lvlupPanel = document.querySelector("#lvlupPanel");
    const lvlupSelect = document.querySelector("#lvlupSelect");
    
    if (!lvlupPanel || !lvlupSelect) {
        console.error("升级弹窗元素未找到");
        return;
    }
    
    safePlaySFX(sfxLvlUp);
    addCombatLog(`系统升级完成！ (Mk.${player.lvl - player.exp.lvlGained} > Mk.${player.lvl})`);

    // Recover 20% extra hp on level up
    player.stats.hp += Math.round((player.stats.hpMax * 20) / 100);
    playerLoadStats();

    // Show popup choices
    lvlupPanel.style.display = "flex";
    const combatPanel = document.querySelector("#combatPanel");
    if (combatPanel) {
        combatPanel.style.filter = "brightness(50%)";
    }
    const percentages = {
        "hp": 10,
        "atk": 8, 
        "def": 8,
        "atkSpd": 3,
        "vamp": 0.5,
        "critRate": 1,
        "critDmg": 6
    };
    
    // 随机生成不同等级的升级值，增加更大的变化范围
    for (let stat in percentages) {
        const baseValue = percentages[stat];
        // 使用更复杂的随机算法，确保能生成各个等级
        let multiplier;
        const rand = Math.random();
        
        // 20%概率生成传说级(180%-250%)
        if (rand < 0.2) {
            multiplier = 1.8 + Math.random() * 0.7;
        }
        // 25%概率生成稀有级(150%-180%) 
        else if (rand < 0.45) {
            multiplier = 1.5 + Math.random() * 0.3;
        }
        // 25%概率生成优秀级(120%-150%)
        else if (rand < 0.7) {
            multiplier = 1.2 + Math.random() * 0.3;
        }
        // 20%概率生成标准级(90%-120%)
        else if (rand < 0.9) {
            multiplier = 0.9 + Math.random() * 0.3;
        }
        // 10%概率生成基础级(60%-90%)
        else {
            multiplier = 0.6 + Math.random() * 0.3;
        }
        
        // 添加额外的随机微调，避免重复
        const microAdjust = (Math.random() - 0.5) * 0.1;
        multiplier += microAdjust;
        
        percentages[stat] = Number((baseValue * multiplier).toFixed(2));
    }
    generateLvlStats(2, percentages);
}

// Generates random stats for level up popup
const generateLvlStats = (rerolls, basePercentages) => {
    const lvlupSelect = document.querySelector("#lvlupSelect");
    const lvlupPanel = document.querySelector("#lvlupPanel");
    
    if (!lvlupSelect || !lvlupPanel) {
        console.error("升级弹窗元素未找到");
        return;
    }
    
    let selectedStats = [];
    let stats = ["hp", "atk", "def", "atkSpd", "vamp", "critRate", "critDmg"];
    while (selectedStats.length < 3) {
        let randomIndex = Math.floor(Math.random() * stats.length);
        if (!selectedStats.includes(stats[randomIndex])) {
            selectedStats.push(stats[randomIndex]);
        }
    }
    
    // 为每个选项生成独立的随机值
    const randomizedValues = {};
    for (let i = 0; i < selectedStats.length; i++) {
        const stat = selectedStats[i];
        const baseValue = basePercentages[stat];
        
        // 为每个选项独立生成随机值 - 直接的百分比范围
        let value;
        const rand = Math.random();
        
        // 根据属性类型设置不同的数值范围
        const valueRanges = {
            "hp": {
                "标准级": [5, 10],      // 5-10点
                "改进级": [10, 20],     // 10-20点
                "军用级": [20, 35],     // 20-35点
                "实验级": [35, 55],     // 35-55点
                "原型级": [55, 80],     // 55-80点
                "遗产级": [80, 120]     // 80-120点
            },
            "atk": {
                "标准级": [3, 6],       // 3-6%
                "改进级": [6, 10],      // 6-10%
                "军用级": [10, 15],     // 10-15%
                "实验级": [15, 22],     // 15-22%
                "原型级": [22, 30],     // 22-30%
                "遗产级": [30, 45]      // 30-45%
            },
            "def": {
                "标准级": [3, 6],       // 3-6%
                "改进级": [6, 10],      // 6-10%
                "军用级": [10, 15],     // 10-15%
                "实验级": [15, 22],     // 15-22%
                "原型级": [22, 30],     // 22-30%
                "遗产级": [30, 45]      // 30-45%
            },
            "atkSpd": {
                "标准级": [1, 2],       // 1-2%
                "改进级": [2, 4],       // 2-4%
                "军用级": [4, 6],       // 4-6%
                "实验级": [6, 9],       // 6-9%
                "原型级": [9, 12],      // 9-12%
                "遗产级": [12, 18]      // 12-18%
            },
            "vamp": {
                "标准级": [0.2, 0.5],   // 0.2-0.5%
                "改进级": [0.5, 1],     // 0.5-1%
                "军用级": [1, 1.5],     // 1-1.5%
                "实验级": [1.5, 2.5],   // 1.5-2.5%
                "原型级": [2.5, 3.5],   // 2.5-3.5%
                "遗产级": [3.5, 5]      // 3.5-5%
            },
            "critRate": {
                "标准级": [0.5, 1],     // 0.5-1%
                "改进级": [1, 2],       // 1-2%
                "军用级": [2, 3],       // 2-3%
                "实验级": [3, 4.5],     // 3-4.5%
                "原型级": [4.5, 6],     // 4.5-6%
                "遗产级": [6, 9]        // 6-9%
            },
            "critDmg": {
                "标准级": [2, 5],       // 2-5%
                "改进级": [5, 8],       // 5-8%
                "军用级": [8, 12],      // 8-12%
                "实验级": [12, 18],     // 12-18%
                "原型级": [18, 25],     // 18-25%
                "遗产级": [25, 35]      // 25-35%
            }
        };
        
        // 确定稀有度
        let rarity;
        if (rand < 0.01) {
            rarity = "遗产级";
        } else if (rand < 0.03) {
            rarity = "原型级";
        } else if (rand < 0.06) {
            rarity = "实验级";
        } else if (rand < 0.1) {
            rarity = "军用级";
        } else if (rand < 0.3) {
            rarity = "改进级";
        } else {
            rarity = "标准级";
        }
        
        // 获取对应的数值范围
        const range = valueRanges[stat][rarity];
        const minValue = range[0];
        const maxValue = range[1];
        
        // 在范围内随机生成数值
        value = minValue + Math.random() * (maxValue - minValue);
        
        // 添加微小随机变化避免重复
        const microAdjust = (Math.random() - 0.5) * 0.1;
        value += microAdjust;
        
        randomizedValues[stat] = Number(value.toFixed(2));
    }
    

    const loadLvlHeader = () => {
        // 清空所有内容，确保没有残留
        lvlupSelect.innerHTML = `
            <h1>系统升级！</h1>
            <div class="content-head">
                <h4>升级点数: ${player.exp.lvlGained}</h4>
                <button id="lvlReroll">重新扫描 ${rerolls}/2</button>
            </div>
        `;
    }
    loadLvlHeader();

    const lvlReroll = document.querySelector("#lvlReroll");
    lvlReroll.addEventListener("click", function () {
        if (rerolls > 0) {
            safePlaySFX(sfxSell);
            rerolls--;
            loadLvlHeader();
            generateLvlStats(rerolls, basePercentages);
        } else {
            safePlaySFX(sfxDeny);
            // 显示看广告弹窗
            showAdRerollModal(basePercentages);
        }
    });

    
    try {
        for (let i = 0; i < 3; i++) {
            
            let button = document.createElement("button");
            button.id = "lvlSlot" + i;
            
            // 获取升级词条等级和样式 - 使用独立的随机值
            const upgradeInfo = getUpgradeInfo(selectedStats[i], randomizedValues[selectedStats[i]]);
            button.className = "upgrade-button " + upgradeInfo.tierClass;
            

            let h3 = document.createElement("h3");
            h3.innerHTML = upgradeInfo.title;
            button.appendChild(h3);

            let p = document.createElement("p");
            p.innerHTML = upgradeInfo.description;
            button.appendChild(p);

            // Increase the selected stat for player
            // 使用闭包来保存当前的stat值
            const currentStat = selectedStats[i];
            const currentValue = randomizedValues[currentStat];
            button.addEventListener("click", function () {
                safePlaySFX(sfxItem);
                player.bonusStats[currentStat] += currentValue;

                if (player.exp.lvlGained > 1) {
                    player.exp.lvlGained--;
                    generateLvlStats(2, basePercentages);
                } else {
                    player.exp.lvlGained = 0;
                    lvlupPanel.style.display = "none";
                    const combatPanel = document.querySelector("#combatPanel");
                    if (combatPanel) {
                        combatPanel.style.filter = "brightness(100%)";
                    }
                    leveled = false;
                }

                playerLoadStats();
                saveData();
            });

            lvlupSelect.appendChild(button);
        }
    } catch (err) { }
}

// 显示看广告恢复重置次数的弹窗
const showAdRerollModal = (percentages) => {
    defaultModalElement.style.display = "flex";
    lvlupPanel.style.filter = "brightness(50%)";
    
    defaultModalElement.innerHTML = `
        <div class="content">
            <h3><i class="fas fa-satellite-dish"></i> 扫描能量耗尽</h3>
            <p>连接到量子广告网络可以补充扫描能量</p>
            <p style="font-size: 0.85rem; opacity: 0.7; margin-top: 0.5rem;">观看时长: 15-30秒</p>
            <div class="button-container">
                <button id="watchAd"><i class="fas fa-play-circle"></i> 连接广告网络</button>
                <button id="cancelAd">稍后再说</button>
            </div>
        </div>
    `;
    
    const watchAdBtn = document.querySelector("#watchAd");
    const cancelAdBtn = document.querySelector("#cancelAd");
    
    watchAdBtn.onclick = function() {
        safePlaySFX(sfxConfirm);
        
        // 广告接口预留位置
        // TODO: 在这里调用广告SDK
        // window.showRewardedAd(() => {
        //     // 广告观看成功回调
        //     grantAdReroll(percentages);
        // }, () => {
        //     // 广告观看失败回调
        //     showAdError();
        // });
        
        // 临时：直接给予奖励
        grantAdReroll(percentages);
    };
    
    cancelAdBtn.onclick = function() {
        safePlaySFX(sfxDecline);
        defaultModalElement.style.display = "none";
        defaultModalElement.innerHTML = "";
        lvlupPanel.style.filter = "brightness(100%)";
    };
};

// 广告观看成功后给予重置次数
const grantAdReroll = (percentages) => {
    defaultModalElement.style.display = "none";
    defaultModalElement.innerHTML = "";
    lvlupPanel.style.filter = "brightness(100%)";
    
    // 给予一次额外的重置机会
    generateLvlStats(1, percentages);
    
    // 显示成功提示
    addCombatLog("通过纳米广告网络获得了额外的扫描机会！");
};




