// 安全区域调试工具
// Safe Area Debug Tool

// 显示安全区域信息的函数
window.showSafeAreaInfo = function() {
    const safeAreaInfo = {
        top: getComputedStyle(document.documentElement).getPropertyValue('--safe-area-inset-top'),
        right: getComputedStyle(document.documentElement).getPropertyValue('--safe-area-inset-right'),
        bottom: getComputedStyle(document.documentElement).getPropertyValue('--safe-area-inset-bottom'),
        left: getComputedStyle(document.documentElement).getPropertyValue('--safe-area-inset-left'),
        statusBarHeight: getComputedStyle(document.documentElement).getPropertyValue('--status-bar-height'),
        windowHeight: window.innerHeight,
        windowWidth: window.innerWidth,
        screenHeight: screen.height,
        screenWidth: screen.width,
        devicePixelRatio: window.devicePixelRatio
    };
    
    console.log('=== 安全区域调试信息 ===');
    console.log('顶部安全区域:', safeAreaInfo.top);
    console.log('右侧安全区域:', safeAreaInfo.right);
    console.log('底部安全区域:', safeAreaInfo.bottom);
    console.log('左侧安全区域:', safeAreaInfo.left);
    console.log('状态栏高度:', safeAreaInfo.statusBarHeight);
    console.log('窗口尺寸:', safeAreaInfo.windowWidth + 'x' + safeAreaInfo.windowHeight);
    console.log('屏幕尺寸:', safeAreaInfo.screenWidth + 'x' + safeAreaInfo.screenHeight);
    console.log('设备像素比:', safeAreaInfo.devicePixelRatio);
    console.log('======================');
    
    return safeAreaInfo;
};

// 切换安全区域可视化的函数
window.toggleSafeAreaDebug = function() {
    const body = document.body;
    if (body.classList.contains('debug-safe-area')) {
        body.classList.remove('debug-safe-area');
        console.log('安全区域调试模式已关闭');
    } else {
        body.classList.add('debug-safe-area');
        console.log('安全区域调试模式已开启');
        
        // 添加调试样式
        if (!document.getElementById('safe-area-debug-style')) {
            const style = document.createElement('style');
            style.id = 'safe-area-debug-style';
            style.textContent = `
                .debug-safe-area::before {
                    content: '';
                    position: fixed;
                    top: 0;
                    left: 0;
                    right: 0;
                    height: var(--safe-area-inset-top);
                    background: rgba(255, 0, 0, 0.3);
                    z-index: 9999;
                    pointer-events: none;
                    border-bottom: 2px solid #ff0000;
                }
                
                .debug-safe-area::after {
                    content: '';
                    position: fixed;
                    bottom: 0;
                    left: 0;
                    right: 0;
                    height: var(--safe-area-inset-bottom);
                    background: rgba(0, 255, 0, 0.3);
                    z-index: 9999;
                    pointer-events: none;
                    border-top: 2px solid #00ff00;
                }
            `;
            document.head.appendChild(style);
        }
    }
};

// 自动检测和报告安全区域支持
window.checkSafeAreaSupport = function() {
    const supportsEnv = CSS.supports('padding', 'env(safe-area-inset-top)');
    const supportsConstant = CSS.supports('padding', 'constant(safe-area-inset-top)');
    const supportsMax = CSS.supports('padding', 'max(0px)');
    
    console.log('=== 安全区域支持检测 ===');
    console.log('支持 env():', supportsEnv);
    console.log('支持 constant():', supportsConstant);
    console.log('支持 max():', supportsMax);
    console.log('用户代理:', navigator.userAgent);
    console.log('========================');
    
    return {
        env: supportsEnv,
        constant: supportsConstant,
        max: supportsMax,
        userAgent: navigator.userAgent
    };
};

// 快捷键支持
document.addEventListener('keydown', function(e) {
    // 按 Ctrl+Shift+S 显示安全区域信息
    if (e.ctrlKey && e.shiftKey && e.key === 'S') {
        e.preventDefault();
        showSafeAreaInfo();
    }
    
    // 按 Ctrl+Shift+D 切换安全区域调试
    if (e.ctrlKey && e.shiftKey && e.key === 'D') {
        e.preventDefault();
        toggleSafeAreaDebug();
    }
    
    // 按 Ctrl+Shift+C 检查安全区域支持
    if (e.ctrlKey && e.shiftKey && e.key === 'C') {
        e.preventDefault();
        checkSafeAreaSupport();
    }
});

// 页面加载时自动检查
window.addEventListener('load', function() {
    // 延迟检查，确保CSS已完全加载
    setTimeout(function() {
        console.log('安全区域调试工具已加载');
        console.log('快捷键:');
        console.log('- Ctrl+Shift+S: 显示安全区域信息');
        console.log('- Ctrl+Shift+D: 切换安全区域可视化');
        console.log('- Ctrl+Shift+C: 检查安全区域支持');
        console.log('函数:');
        console.log('- showSafeAreaInfo(): 显示安全区域信息');
        console.log('- toggleSafeAreaDebug(): 切换调试模式');
        console.log('- checkSafeAreaSupport(): 检查支持情况');
        
        // 自动检查支持情况
        checkSafeAreaSupport();
    }, 1000);
});