// 主题管理
class ThemeManager {
    constructor() {
        this.themes = ['gray', 'white'];
        this.currentTheme = 0; // 默认为灰色主题
        this.init();
    }

    init() {
        // 从本地存储加载主题
        const savedTheme = localStorage.getItem('dungeonTheme');
        if (savedTheme) {
            this.currentTheme = parseInt(savedTheme);
        }
        this.applyTheme();
        this.updateButton();
    }

    toggleTheme() {
        this.currentTheme = (this.currentTheme + 1) % this.themes.length;
        this.applyTheme();
        this.updateButton();
        this.saveTheme();
    }

    applyTheme() {
        const body = document.body;
        // 移除所有主题类
        body.classList.remove('theme-white');
        
        // 应用新主题 - 如果是白色主题则添加类，灰色主题不需要类
        if (this.themes[this.currentTheme] === 'white') {
            body.classList.add('theme-white');
        }
    }

    updateButton() {
        const button = document.getElementById('theme-toggle');
        if (button) {
            const names = ['深空模式', '光能模式'];
            button.title = `当前主题: ${names[this.currentTheme]}`;
            const icon = button.querySelector('i');
            if (icon) {
                // 移除文本，使用CSS设计的图标
                icon.textContent = '';
                icon.className = `theme-icon theme-${this.currentTheme}`;
            }
        }
    }

    saveTheme() {
        localStorage.setItem('dungeonTheme', this.currentTheme.toString());
    }
}

// 全局主题管理器
let themeManager;

// 主题切换函数
function toggleTheme() {
    if (!themeManager) {
        themeManager = new ThemeManager();
    }
    themeManager.toggleTheme();
}

// 页面加载时初始化主题
document.addEventListener('DOMContentLoaded', function() {
    themeManager = new ThemeManager();
});