// ========== 调试配置 ==========
// 控制调试功能的开关 - 发布正式版时将此设为false
const DEBUG_MODE = false;

// 启用移动端调试悬浮球的方法
window.enableMobileDebug = () => {
    localStorage.setItem('mobileDebug', 'true');
    console.log('移动端调试已启用，刷新页面生效');
};

// 禁用移动端调试悬浮球的方法
window.disableMobileDebug = () => {
    localStorage.removeItem('mobileDebug');
    console.log('移动端调试已禁用，刷新页面生效');
};

// 安全的数值验证函数
const safeNumber = (value, defaultValue = 0) => {
    if (typeof value !== 'number' || isNaN(value) || !isFinite(value)) {
        console.warn('safeNumber: 无效数值', value, '使用默认值', defaultValue);
        return defaultValue;
    }
    return value;
};

// Format large numbers
const nFormatter = (num) => {
    // 首先验证输入数值
    num = safeNumber(num, 0);
    
    let lookup = [
        { value: 1, symbol: "" },
        { value: 1e3, symbol: "千" },
        { value: 1e6, symbol: "百万" },
        { value: 1e9, symbol: "亿" },
        { value: 1e12, symbol: "兆" },
        { value: 1e15, symbol: "万亿" },
        { value: 1e18, symbol: "千万亿" }
    ];
    let rx = /\.0+$|(\.[0-9]*[1-9])0+$/;
    let item = lookup.slice().reverse().find(function (item) {
        return num >= item.value;
    });
    
    if (item) {
        const result = (num / item.value).toFixed(2).replace(rx, "$1") + item.symbol;
        return result;
    } else {
        // 如果找不到匹配项，直接返回数值
        return num.toString();
    }
}

// Get a randomized number between 2 integers
const randomizeNum = (min, max) => {
    min = safeNumber(min, 0);
    max = safeNumber(max, 1);
    
    // 确保 min <= max
    if (min > max) {
        [min, max] = [max, min];
    }
    
    min = Math.ceil(min);
    max = Math.floor(max);
    const result = Math.round(Math.floor(Math.random() * (max - min + 1)) + min);
    return safeNumber(result, min);
}

// Get a randomized decimal between 2 numbers
const randomizeDecimal = (min, max) => {
    min = safeNumber(min, 0);
    max = safeNumber(max, 1);
    
    // 确保 min <= max
    if (min > max) {
        [min, max] = [max, min];
    }
    
    const result = Math.random() * (max - min) + min;
    return safeNumber(result, min);
}

// 安全的金币操作函数
const safeAddGold = (amount) => {
    amount = safeNumber(amount, 0);
    if (amount <= 0) return;
    
    const currentGold = safeNumber(player.gold, 0);
    player.gold = currentGold + amount;
    console.log(`金币增加: +${amount}, 当前总金币: ${player.gold}`);
}

const safeSubtractGold = (amount) => {
    amount = safeNumber(amount, 0);
    if (amount <= 0) return true;
    
    const currentGold = safeNumber(player.gold, 0);
    if (currentGold >= amount) {
        player.gold = currentGold - amount;
        console.log(`金币减少: -${amount}, 当前总金币: ${player.gold}`);
        return true;
    }
    return false;
}

// 调试函数：检查金币显示状态
const debugGoldDisplay = () => {
    console.log('=== 金币显示调试信息 ===');
    console.log('player.gold 原始值:', player.gold);
    console.log('player.gold 类型:', typeof player.gold);
    console.log('safeNumber 处理后:', safeNumber(player.gold, 0));
    console.log('nFormatter 格式化后:', nFormatter(player.gold));
}

// saveData函数在main.js中定义

// 紧急金币恢复函数
const emergencyGoldFix = () => {
    const currentGold = safeNumber(player.gold, 0);
    if (currentGold <= 0 || isNaN(currentGold) || !isFinite(currentGold)) {
        console.warn('检测到异常金币状态，正在恢复...');
        console.log('异常金币值:', player.gold);
        player.gold = Math.max(100, dungeon.floor * 50); // 基于当前星区给予合理金币
        console.log('金币已恢复至:', player.gold);
        saveData();
        playerLoadStats();
        return true;
    }
    return false;
    
    const goldElement = document.querySelector("#player-gold");
    if (goldElement) {
        console.log('金币显示元素内容:', goldElement.innerHTML);
    } else {
        console.log('未找到金币显示元素 #player-gold');
    }
    console.log('========================');
}